@@ -13,8 +13,8 @@
 #define DNS_VIEW_H 1
 
 /*****
- ***** Module Info
- *****/
+***** Module Info
+*****/
 
 /*! \file dns/view.h
  * \brief
@@ -171,19 +171,20 @@ struct dns_view {
 	uint16_t	      maxudp;
 	dns_ttl_t	      staleanswerttl;
 	dns_stale_answer_t    staleanswersok;	  /* rndc setting */
-	bool		      staleanswersenable; /* named.conf setting */
-	uint16_t	      nocookieudp;
-	uint16_t	      padding;
-	dns_acl_t *	      pad_acl;
-	unsigned int	      maxbits;
-	dns_dns64list_t	      dns64;
-	unsigned int	      dns64cnt;
-	dns_rpz_zones_t *     rpzs;
-	dns_catz_zones_t *    catzs;
-	dns_dlzdblist_t	      dlz_searched;
-	dns_dlzdblist_t	      dlz_unsearched;
-	uint32_t	      fail_ttl;
-	dns_badcache_t *      failcache;
+	bool		      staleanswersenable; /* named.conf setting
+						   * */
+	uint16_t	  nocookieudp;
+	uint16_t	  padding;
+	dns_acl_t *	  pad_acl;
+	unsigned int	  maxbits;
+	dns_dns64list_t	  dns64;
+	unsigned int	  dns64cnt;
+	dns_rpz_zones_t * rpzs;
+	dns_catz_zones_t *catzs;
+	dns_dlzdblist_t	  dlz_searched;
+	dns_dlzdblist_t	  dlz_unsearched;
+	uint32_t	  fail_ttl;
+	dns_badcache_t *  failcache;
 
 	/*
 	 * Configurable data for server use only,
@@ -230,7 +231,7 @@ struct dns_view {
 
 	dns_dtenv_t *	dtenv;	 /* Dnstap environment */
 	dns_dtmsgtype_t dttypes; /* Dnstap message types
-				    to log */
+				  * to log */
 
 	/* Registered module instances */
 	void *plugins;
@@ -241,7 +242,7 @@ struct dns_view {
 	void (*hooktable_free)(isc_mem_t *, void **);
 };
 
-#define DNS_VIEW_MAGIC ISC_MAGIC('V', 'i', 'e', 'w')
+#define DNS_VIEW_MAGIC	     ISC_MAGIC('V', 'i', 'e', 'w')
 #define DNS_VIEW_VALID(view) ISC_MAGIC_VALID(view, DNS_VIEW_MAGIC)
 
 #define DNS_VIEWATTR_RESSHUTDOWN 0x01
