@@ -20,18 +20,19 @@
 #include <isc/string.h>
 #include <isc/util.h>
 
-#include <dns/keyvalues.h>
-
-#include "dst_internal.h"
-#include "dst_parse.h"
-#include "dst_pkcs11.h"
-
-#include <dst/result.h>
 #include <pk11/constants.h>
 #include <pk11/internal.h>
 #include <pk11/pk11.h>
 #include <pkcs11/pkcs11.h>
 
+#include <dns/keyvalues.h>
+
+#include <dst/result.h>
+
+#include "dst_internal.h"
+#include "dst_parse.h"
+#include "dst_pkcs11.h"
+
 /*
  * FIPS 186-3 ECDSA keys:
  *  mechanisms:
@@ -53,7 +54,7 @@
  */
 
 #define TAG_OCTECT_STRING 0x04
-#define UNCOMPRESSED 0x04
+#define UNCOMPRESSED	  0x04
 
 #define DST_RET(a)        \
 	{                 \
@@ -73,34 +74,36 @@ pkcs11ecdsa_fetch(dst_key_t *key, const char *engine, const char *label,
 		  dst_key_t *pub);
 
 static isc_result_t
-pkcs11ecdsa_createctx(dst_key_t *key, dst_context_t *dctx)
-{
-	CK_RV		rv;
-	CK_MECHANISM	mech = { 0, NULL, 0 };
-	CK_SLOT_ID	slotid;
+pkcs11ecdsa_createctx(dst_key_t *key, dst_context_t *dctx) {
+	CK_RV rv;
+	CK_MECHANISM mech = { 0, NULL, 0 };
+	CK_SLOT_ID slotid;
 	pk11_context_t *pk11_ctx;
-	pk11_object_t * ec = key->keydata.pkey;
-	isc_result_t	ret;
+	pk11_object_t *ec = key->keydata.pkey;
+	isc_result_t ret;
 
 	REQUIRE(dctx->key->key_alg == DST_ALG_ECDSA256 ||
 		dctx->key->key_alg == DST_ALG_ECDSA384);
 	REQUIRE(ec != NULL);
 
-	if (dctx->key->key_alg == DST_ALG_ECDSA256)
+	if (dctx->key->key_alg == DST_ALG_ECDSA256) {
 		mech.mechanism = CKM_SHA256;
-	else
+	} else {
 		mech.mechanism = CKM_SHA384;
+	}
 
 	pk11_ctx = isc_mem_get(dctx->mctx, sizeof(*pk11_ctx));
 	memset(pk11_ctx, 0, sizeof(*pk11_ctx));
-	if (ec->ontoken && (dctx->use == DO_SIGN))
+	if (ec->ontoken && (dctx->use == DO_SIGN)) {
 		slotid = ec->slot;
-	else
+	} else {
 		slotid = pk11_get_best_token(OP_ECDSA);
+	}
 	ret = pk11_get_session(pk11_ctx, OP_ECDSA, true, false, ec->reqlogon,
 			       NULL, slotid);
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		goto err;
+	}
 
 	PK11_RET(pkcs_C_DigestInit, (pk11_ctx->session, &mech), ISC_R_FAILURE);
 	dctx->ctxdata.pk11_ctx = pk11_ctx;
@@ -115,10 +118,9 @@ err:
 }
 
 static void
-pkcs11ecdsa_destroyctx(dst_context_t *dctx)
-{
-	CK_BYTE		garbage[ISC_SHA384_DIGESTLENGTH];
-	CK_ULONG	len = ISC_SHA384_DIGESTLENGTH;
+pkcs11ecdsa_destroyctx(dst_context_t *dctx) {
+	CK_BYTE garbage[ISC_SHA384_DIGESTLENGTH];
+	CK_ULONG len = ISC_SHA384_DIGESTLENGTH;
 	pk11_context_t *pk11_ctx = dctx->ctxdata.pk11_ctx;
 
 	REQUIRE(dctx->key->key_alg == DST_ALG_ECDSA256 ||
@@ -135,11 +137,10 @@ pkcs11ecdsa_destroyctx(dst_context_t *dctx)
 }
 
 static isc_result_t
-pkcs11ecdsa_adddata(dst_context_t *dctx, const isc_region_t *data)
-{
-	CK_RV		rv;
+pkcs11ecdsa_adddata(dst_context_t *dctx, const isc_region_t *data) {
+	CK_RV rv;
 	pk11_context_t *pk11_ctx = dctx->ctxdata.pk11_ctx;
-	isc_result_t	ret = ISC_R_SUCCESS;
+	isc_result_t ret = ISC_R_SUCCESS;
 
 	REQUIRE(dctx->key->key_alg == DST_ALG_ECDSA256 ||
 		dctx->key->key_alg == DST_ALG_ECDSA384);
@@ -153,32 +154,31 @@ pkcs11ecdsa_adddata(dst_context_t *dctx, const isc_region_t *data)
 }
 
 static isc_result_t
-pkcs11ecdsa_sign(dst_context_t *dctx, isc_buffer_t *sig)
-{
-	CK_RV		 rv;
-	CK_MECHANISM	 mech = { CKM_ECDSA, NULL, 0 };
+pkcs11ecdsa_sign(dst_context_t *dctx, isc_buffer_t *sig) {
+	CK_RV rv;
+	CK_MECHANISM mech = { CKM_ECDSA, NULL, 0 };
 	CK_OBJECT_HANDLE hKey = CK_INVALID_HANDLE;
-	CK_OBJECT_CLASS	 keyClass = CKO_PRIVATE_KEY;
-	CK_KEY_TYPE	 keyType = CKK_EC;
-	CK_ATTRIBUTE	 keyTemplate[] = {
-		    { CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
-		    { CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
-		    { CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_SIGN, &truevalue, (CK_ULONG)sizeof(truevalue) },
-		    { CKA_EC_PARAMS, NULL, 0 },
-		    { CKA_VALUE, NULL, 0 }
+	CK_OBJECT_CLASS keyClass = CKO_PRIVATE_KEY;
+	CK_KEY_TYPE keyType = CKK_EC;
+	CK_ATTRIBUTE keyTemplate[] = {
+		{ CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
+		{ CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
+		{ CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_SIGN, &truevalue, (CK_ULONG)sizeof(truevalue) },
+		{ CKA_EC_PARAMS, NULL, 0 },
+		{ CKA_VALUE, NULL, 0 }
 	};
-	CK_ATTRIBUTE *	attr;
-	CK_BYTE		digest[ISC_SHA384_DIGESTLENGTH];
-	CK_ULONG	dgstlen;
-	CK_ULONG	siglen;
+	CK_ATTRIBUTE *attr;
+	CK_BYTE digest[ISC_SHA384_DIGESTLENGTH];
+	CK_ULONG dgstlen;
+	CK_ULONG siglen;
 	pk11_context_t *pk11_ctx = dctx->ctxdata.pk11_ctx;
-	dst_key_t *	key = dctx->key;
-	pk11_object_t * ec = key->keydata.pkey;
-	isc_region_t	r;
-	isc_result_t	ret = ISC_R_SUCCESS;
-	unsigned int	i;
+	dst_key_t *key = dctx->key;
+	pk11_object_t *ec = key->keydata.pkey;
+	isc_region_t r;
+	isc_result_t ret = ISC_R_SUCCESS;
+	unsigned int i;
 
 	REQUIRE(key->key_alg == DST_ALG_ECDSA256 ||
 		key->key_alg == DST_ALG_ECDSA384);
@@ -196,8 +196,9 @@ pkcs11ecdsa_sign(dst_context_t *dctx, isc_buffer_t *sig)
 		 ISC_R_FAILURE);
 
 	isc_buffer_availableregion(sig, &r);
-	if (r.length < siglen)
+	if (r.length < siglen) {
 		DST_RET(ISC_R_NOSPACE);
+	}
 
 	if (ec->ontoken && (ec->object != CK_INVALID_HANDLE)) {
 		pk11_ctx->ontoken = ec->ontoken;
@@ -210,16 +211,16 @@ pkcs11ecdsa_sign(dst_context_t *dctx, isc_buffer_t *sig)
 		switch (attr->type) {
 		case CKA_EC_PARAMS:
 			INSIST(keyTemplate[5].type == attr->type);
-			keyTemplate[5].pValue =
-				isc_mem_get(dctx->mctx, attr->ulValueLen);
+			keyTemplate[5].pValue = isc_mem_get(dctx->mctx,
+							    attr->ulValueLen);
 			memmove(keyTemplate[5].pValue, attr->pValue,
 				attr->ulValueLen);
 			keyTemplate[5].ulValueLen = attr->ulValueLen;
 			break;
 		case CKA_VALUE:
 			INSIST(keyTemplate[6].type == attr->type);
-			keyTemplate[6].pValue =
-				isc_mem_get(dctx->mctx, attr->ulValueLen);
+			keyTemplate[6].pValue = isc_mem_get(dctx->mctx,
+							    attr->ulValueLen);
 			memmove(keyTemplate[6].pValue, attr->pValue,
 				attr->ulValueLen);
 			keyTemplate[6].ulValueLen = attr->ulValueLen;
@@ -247,15 +248,19 @@ token_key:
 
 err:
 
-	if (hKey != CK_INVALID_HANDLE)
+	if (hKey != CK_INVALID_HANDLE) {
 		(void)pkcs_C_DestroyObject(pk11_ctx->session, hKey);
-	for (i = 5; i <= 6; i++)
+	}
+	for (i = 5; i <= 6; i++) {
 		if (keyTemplate[i].pValue != NULL) {
-			memset(keyTemplate[i].pValue, 0,
-			       keyTemplate[i].ulValueLen);
-			isc_mem_put(dctx->mctx, keyTemplate[i].pValue,
-				    keyTemplate[i].ulValueLen);
+			{
+				memset(keyTemplate[i].pValue, 0,
+				       keyTemplate[i].ulValueLen);
+				isc_mem_put(dctx->mctx, keyTemplate[i].pValue,
+					    keyTemplate[i].ulValueLen);
+			}
 		}
+	}
 	pk11_return_session(pk11_ctx);
 	memset(pk11_ctx, 0, sizeof(*pk11_ctx));
 	isc_mem_put(dctx->mctx, pk11_ctx, sizeof(*pk11_ctx));
@@ -265,39 +270,39 @@ err:
 }
 
 static isc_result_t
-pkcs11ecdsa_verify(dst_context_t *dctx, const isc_region_t *sig)
-{
-	CK_RV		 rv;
-	CK_MECHANISM	 mech = { CKM_ECDSA, NULL, 0 };
+pkcs11ecdsa_verify(dst_context_t *dctx, const isc_region_t *sig) {
+	CK_RV rv;
+	CK_MECHANISM mech = { CKM_ECDSA, NULL, 0 };
 	CK_OBJECT_HANDLE hKey = CK_INVALID_HANDLE;
-	CK_OBJECT_CLASS	 keyClass = CKO_PUBLIC_KEY;
-	CK_KEY_TYPE	 keyType = CKK_EC;
-	CK_ATTRIBUTE	 keyTemplate[] = {
-		    { CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
-		    { CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
-		    { CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_VERIFY, &truevalue, (CK_ULONG)sizeof(truevalue) },
-		    { CKA_EC_PARAMS, NULL, 0 },
-		    { CKA_EC_POINT, NULL, 0 }
+	CK_OBJECT_CLASS keyClass = CKO_PUBLIC_KEY;
+	CK_KEY_TYPE keyType = CKK_EC;
+	CK_ATTRIBUTE keyTemplate[] = {
+		{ CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
+		{ CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
+		{ CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_VERIFY, &truevalue, (CK_ULONG)sizeof(truevalue) },
+		{ CKA_EC_PARAMS, NULL, 0 },
+		{ CKA_EC_POINT, NULL, 0 }
 	};
-	CK_ATTRIBUTE *	attr;
-	CK_BYTE		digest[ISC_SHA384_DIGESTLENGTH];
-	CK_ULONG	dgstlen;
+	CK_ATTRIBUTE *attr;
+	CK_BYTE digest[ISC_SHA384_DIGESTLENGTH];
+	CK_ULONG dgstlen;
 	pk11_context_t *pk11_ctx = dctx->ctxdata.pk11_ctx;
-	dst_key_t *	key = dctx->key;
-	pk11_object_t * ec = key->keydata.pkey;
-	isc_result_t	ret = ISC_R_SUCCESS;
-	unsigned int	i;
+	dst_key_t *key = dctx->key;
+	pk11_object_t *ec = key->keydata.pkey;
+	isc_result_t ret = ISC_R_SUCCESS;
+	unsigned int i;
 
 	REQUIRE(key->key_alg == DST_ALG_ECDSA256 ||
 		key->key_alg == DST_ALG_ECDSA384);
 	REQUIRE(ec != NULL);
 
-	if (key->key_alg == DST_ALG_ECDSA256)
+	if (key->key_alg == DST_ALG_ECDSA256) {
 		dgstlen = ISC_SHA256_DIGESTLENGTH;
-	else
+	} else {
 		dgstlen = ISC_SHA384_DIGESTLENGTH;
+	}
 
 	PK11_RET(pkcs_C_DigestFinal, (pk11_ctx->session, digest, &dgstlen),
 		 ISC_R_FAILURE);
@@ -307,16 +312,16 @@ pkcs11ecdsa_verify(dst_context_t *dctx, const isc_region_t *sig)
 		switch (attr->type) {
 		case CKA_EC_PARAMS:
 			INSIST(keyTemplate[5].type == attr->type);
-			keyTemplate[5].pValue =
-				isc_mem_get(dctx->mctx, attr->ulValueLen);
+			keyTemplate[5].pValue = isc_mem_get(dctx->mctx,
+							    attr->ulValueLen);
 			memmove(keyTemplate[5].pValue, attr->pValue,
 				attr->ulValueLen);
 			keyTemplate[5].ulValueLen = attr->ulValueLen;
 			break;
 		case CKA_EC_POINT:
 			INSIST(keyTemplate[6].type == attr->type);
-			keyTemplate[6].pValue =
-				isc_mem_get(dctx->mctx, attr->ulValueLen);
+			keyTemplate[6].pValue = isc_mem_get(dctx->mctx,
+							    attr->ulValueLen);
 			memmove(keyTemplate[6].pValue, attr->pValue,
 				attr->ulValueLen);
 			keyTemplate[6].ulValueLen = attr->ulValueLen;
@@ -338,15 +343,19 @@ pkcs11ecdsa_verify(dst_context_t *dctx, const isc_region_t *sig)
 
 err:
 
-	if (hKey != CK_INVALID_HANDLE)
+	if (hKey != CK_INVALID_HANDLE) {
 		(void)pkcs_C_DestroyObject(pk11_ctx->session, hKey);
-	for (i = 5; i <= 6; i++)
+	}
+	for (i = 5; i <= 6; i++) {
 		if (keyTemplate[i].pValue != NULL) {
-			memset(keyTemplate[i].pValue, 0,
-			       keyTemplate[i].ulValueLen);
-			isc_mem_put(dctx->mctx, keyTemplate[i].pValue,
-				    keyTemplate[i].ulValueLen);
+			{
+				memset(keyTemplate[i].pValue, 0,
+				       keyTemplate[i].ulValueLen);
+				isc_mem_put(dctx->mctx, keyTemplate[i].pValue,
+					    keyTemplate[i].ulValueLen);
+			}
 		}
+	}
 	pk11_return_session(pk11_ctx);
 	memset(pk11_ctx, 0, sizeof(*pk11_ctx));
 	isc_mem_put(dctx->mctx, pk11_ctx, sizeof(*pk11_ctx));
@@ -356,38 +365,42 @@ err:
 }
 
 static bool
-pkcs11ecdsa_compare(const dst_key_t *key1, const dst_key_t *key2)
-{
+pkcs11ecdsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	pk11_object_t *ec1, *ec2;
-	CK_ATTRIBUTE * attr1, *attr2;
+	CK_ATTRIBUTE *attr1, *attr2;
 
 	ec1 = key1->keydata.pkey;
 	ec2 = key2->keydata.pkey;
 
-	if ((ec1 == NULL) && (ec2 == NULL))
+	if ((ec1 == NULL) && (ec2 == NULL)) {
 		return (true);
-	else if ((ec1 == NULL) || (ec2 == NULL))
+	} else if ((ec1 == NULL) || (ec2 == NULL)) {
 		return (false);
+	}
 
 	attr1 = pk11_attribute_bytype(ec1, CKA_EC_PARAMS);
 	attr2 = pk11_attribute_bytype(ec2, CKA_EC_PARAMS);
-	if ((attr1 == NULL) && (attr2 == NULL))
+	if ((attr1 == NULL) && (attr2 == NULL)) {
 		return (true);
-	else if ((attr1 == NULL) || (attr2 == NULL) ||
-		 (attr1->ulValueLen != attr2->ulValueLen) ||
-		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
-				    attr1->ulValueLen))
+	} else if ((attr1 == NULL) || (attr2 == NULL) ||
+		   (attr1->ulValueLen != attr2->ulValueLen) ||
+		   !isc_safe_memequal(attr1->pValue, attr2->pValue,
+				      attr1->ulValueLen))
+	{
 		return (false);
+	}
 
 	attr1 = pk11_attribute_bytype(ec1, CKA_EC_POINT);
 	attr2 = pk11_attribute_bytype(ec2, CKA_EC_POINT);
-	if ((attr1 == NULL) && (attr2 == NULL))
+	if ((attr1 == NULL) && (attr2 == NULL)) {
 		return (true);
-	else if ((attr1 == NULL) || (attr2 == NULL) ||
-		 (attr1->ulValueLen != attr2->ulValueLen) ||
-		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
-				    attr1->ulValueLen))
+	} else if ((attr1 == NULL) || (attr2 == NULL) ||
+		   (attr1->ulValueLen != attr2->ulValueLen) ||
+		   !isc_safe_memequal(attr1->pValue, attr2->pValue,
+				      attr1->ulValueLen))
+	{
 		return (false);
+	}
 
 	attr1 = pk11_attribute_bytype(ec1, CKA_VALUE);
 	attr2 = pk11_attribute_bytype(ec2, CKA_VALUE);
@@ -396,31 +409,35 @@ pkcs11ecdsa_compare(const dst_key_t *key1, const dst_key_t *key2)
 	     (attr1->ulValueLen != attr2->ulValueLen) ||
 	     !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				attr1->ulValueLen)))
+	{
 		return (false);
+	}
 
-	if (!ec1->ontoken && !ec2->ontoken)
+	if (!ec1->ontoken && !ec2->ontoken) {
 		return (true);
-	else if (ec1->ontoken || ec2->ontoken || (ec1->object != ec2->object))
+	} else if (ec1->ontoken || ec2->ontoken || (ec1->object != ec2->object))
+	{
 		return (false);
+	}
 
 	return (true);
 }
 
-#define SETCURVE()                                                           \
-	if (key->key_alg == DST_ALG_ECDSA256) {                              \
-		attr->pValue =                                               \
-			isc_mem_get(key->mctx, sizeof(pk11_ecc_prime256v1)); \
-                                                                             \
-		memmove(attr->pValue, pk11_ecc_prime256v1,                   \
-			sizeof(pk11_ecc_prime256v1));                        \
-		attr->ulValueLen = sizeof(pk11_ecc_prime256v1);              \
-	} else {                                                             \
-		attr->pValue =                                               \
-			isc_mem_get(key->mctx, sizeof(pk11_ecc_secp384r1));  \
-                                                                             \
-		memmove(attr->pValue, pk11_ecc_secp384r1,                    \
-			sizeof(pk11_ecc_secp384r1));                         \
-		attr->ulValueLen = sizeof(pk11_ecc_secp384r1);               \
+#define SETCURVE()                                                       \
+	if (key->key_alg == DST_ALG_ECDSA256) {                          \
+		attr->pValue = isc_mem_get(key->mctx,                    \
+					   sizeof(pk11_ecc_prime256v1)); \
+                                                                         \
+		memmove(attr->pValue, pk11_ecc_prime256v1,               \
+			sizeof(pk11_ecc_prime256v1));                    \
+		attr->ulValueLen = sizeof(pk11_ecc_prime256v1);          \
+	} else {                                                         \
+		attr->pValue = isc_mem_get(key->mctx,                    \
+					   sizeof(pk11_ecc_secp384r1));  \
+                                                                         \
+		memmove(attr->pValue, pk11_ecc_secp384r1,                \
+			sizeof(pk11_ecc_secp384r1));                     \
+		attr->ulValueLen = sizeof(pk11_ecc_secp384r1);           \
 	}
 
 #define FREECURVE()                                                     \
@@ -431,36 +448,35 @@ pkcs11ecdsa_compare(const dst_key_t *key1, const dst_key_t *key2)
 	}
 
 static isc_result_t
-pkcs11ecdsa_generate(dst_key_t *key, int unused, void (*callback)(int))
-{
-	CK_RV		 rv;
-	CK_MECHANISM	 mech = { CKM_EC_KEY_PAIR_GEN, NULL, 0 };
+pkcs11ecdsa_generate(dst_key_t *key, int unused, void (*callback)(int)) {
+	CK_RV rv;
+	CK_MECHANISM mech = { CKM_EC_KEY_PAIR_GEN, NULL, 0 };
 	CK_OBJECT_HANDLE pub = CK_INVALID_HANDLE;
-	CK_OBJECT_CLASS	 pubClass = CKO_PUBLIC_KEY;
-	CK_KEY_TYPE	 keyType = CKK_EC;
-	CK_ATTRIBUTE	 pubTemplate[] = {
-		    { CKA_CLASS, &pubClass, (CK_ULONG)sizeof(pubClass) },
-		    { CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
-		    { CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_VERIFY, &truevalue, (CK_ULONG)sizeof(truevalue) },
-		    { CKA_EC_PARAMS, NULL, 0 }
+	CK_OBJECT_CLASS pubClass = CKO_PUBLIC_KEY;
+	CK_KEY_TYPE keyType = CKK_EC;
+	CK_ATTRIBUTE pubTemplate[] = {
+		{ CKA_CLASS, &pubClass, (CK_ULONG)sizeof(pubClass) },
+		{ CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
+		{ CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_VERIFY, &truevalue, (CK_ULONG)sizeof(truevalue) },
+		{ CKA_EC_PARAMS, NULL, 0 }
 	};
 	CK_OBJECT_HANDLE priv = CK_INVALID_HANDLE;
 	CK_OBJECT_HANDLE privClass = CKO_PRIVATE_KEY;
-	CK_ATTRIBUTE	 privTemplate[] = {
-		    { CKA_CLASS, &privClass, (CK_ULONG)sizeof(privClass) },
-		    { CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
-		    { CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_SENSITIVE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
-		    { CKA_EXTRACTABLE, &truevalue, (CK_ULONG)sizeof(truevalue) },
-		    { CKA_SIGN, &truevalue, (CK_ULONG)sizeof(truevalue) }
+	CK_ATTRIBUTE privTemplate[] = {
+		{ CKA_CLASS, &privClass, (CK_ULONG)sizeof(privClass) },
+		{ CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
+		{ CKA_TOKEN, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_PRIVATE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_SENSITIVE, &falsevalue, (CK_ULONG)sizeof(falsevalue) },
+		{ CKA_EXTRACTABLE, &truevalue, (CK_ULONG)sizeof(truevalue) },
+		{ CKA_SIGN, &truevalue, (CK_ULONG)sizeof(truevalue) }
 	};
-	CK_ATTRIBUTE *	attr;
-	pk11_object_t * ec;
+	CK_ATTRIBUTE *attr;
+	pk11_object_t *ec;
 	pk11_context_t *pk11_ctx;
-	isc_result_t	ret;
+	isc_result_t ret;
 
 	REQUIRE(key->key_alg == DST_ALG_ECDSA256 ||
 		key->key_alg == DST_ALG_ECDSA384);
@@ -470,8 +486,9 @@ pkcs11ecdsa_generate(dst_key_t *key, int unused, void (*callback)(int))
 	pk11_ctx = isc_mem_get(key->mctx, sizeof(*pk11_ctx));
 	ret = pk11_get_session(pk11_ctx, OP_ECDSA, true, false, false, NULL,
 			       pk11_get_best_token(OP_ECDSA));
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		goto err;
+	}
 
 	ec = isc_mem_get(key->mctx, sizeof(*ec));
 	memset(ec, 0, sizeof(*ec));
@@ -521,19 +538,22 @@ pkcs11ecdsa_generate(dst_key_t *key, int unused, void (*callback)(int))
 	memset(pk11_ctx, 0, sizeof(*pk11_ctx));
 	isc_mem_put(key->mctx, pk11_ctx, sizeof(*pk11_ctx));
 
-	if (key->key_alg == DST_ALG_ECDSA256)
+	if (key->key_alg == DST_ALG_ECDSA256) {
 		key->key_size = DNS_KEY_ECDSA256SIZE * 4;
-	else
+	} else {
 		key->key_size = DNS_KEY_ECDSA384SIZE * 4;
+	}
 
 	return (ISC_R_SUCCESS);
 
 err:
 	pkcs11ecdsa_destroy(key);
-	if (priv != CK_INVALID_HANDLE)
+	if (priv != CK_INVALID_HANDLE) {
 		(void)pkcs_C_DestroyObject(pk11_ctx->session, priv);
-	if (pub != CK_INVALID_HANDLE)
+	}
+	if (pub != CK_INVALID_HANDLE) {
 		(void)pkcs_C_DestroyObject(pk11_ctx->session, pub);
+	}
 	pk11_return_session(pk11_ctx);
 	memset(pk11_ctx, 0, sizeof(*pk11_ctx));
 	isc_mem_put(key->mctx, pk11_ctx, sizeof(*pk11_ctx));
@@ -542,25 +562,25 @@ err:
 }
 
 static bool
-pkcs11ecdsa_isprivate(const dst_key_t *key)
-{
+pkcs11ecdsa_isprivate(const dst_key_t *key) {
 	pk11_object_t *ec = key->keydata.pkey;
-	CK_ATTRIBUTE * attr;
+	CK_ATTRIBUTE *attr;
 
-	if (ec == NULL)
+	if (ec == NULL) {
 		return (false);
+	}
 	attr = pk11_attribute_bytype(ec, CKA_VALUE);
 	return (attr != NULL || ec->ontoken);
 }
 
 static void
-pkcs11ecdsa_destroy(dst_key_t *key)
-{
+pkcs11ecdsa_destroy(dst_key_t *key) {
 	pk11_object_t *ec = key->keydata.pkey;
-	CK_ATTRIBUTE * attr;
+	CK_ATTRIBUTE *attr;
 
-	if (ec == NULL)
+	if (ec == NULL) {
 		return;
+	}
 
 	INSIST((ec->object == CK_INVALID_HANDLE) || ec->ontoken);
 
@@ -585,19 +605,19 @@ pkcs11ecdsa_destroy(dst_key_t *key)
 }
 
 static isc_result_t
-pkcs11ecdsa_todns(const dst_key_t *key, isc_buffer_t *data)
-{
+pkcs11ecdsa_todns(const dst_key_t *key, isc_buffer_t *data) {
 	pk11_object_t *ec;
-	isc_region_t   r;
-	unsigned int   len;
-	CK_ATTRIBUTE * attr;
+	isc_region_t r;
+	unsigned int len;
+	CK_ATTRIBUTE *attr;
 
 	REQUIRE(key->keydata.pkey != NULL);
 
-	if (key->key_alg == DST_ALG_ECDSA256)
+	if (key->key_alg == DST_ALG_ECDSA256) {
 		len = DNS_KEY_ECDSA256SIZE;
-	else
+	} else {
 		len = DNS_KEY_ECDSA384SIZE;
+	}
 
 	ec = key->keydata.pkey;
 	attr = pk11_attribute_bytype(ec, CKA_EC_POINT);
@@ -605,11 +625,14 @@ pkcs11ecdsa_todns(const dst_key_t *key, isc_buffer_t *data)
 	    (((CK_BYTE_PTR)attr->pValue)[0] != TAG_OCTECT_STRING) ||
 	    (((CK_BYTE_PTR)attr->pValue)[1] != len + 1) ||
 	    (((CK_BYTE_PTR)attr->pValue)[2] != UNCOMPRESSED))
+	{
 		return (ISC_R_FAILURE);
+	}
 
 	isc_buffer_availableregion(data, &r);
-	if (r.length < len)
+	if (r.length < len) {
 		return (ISC_R_NOSPACE);
+	}
 	memmove(r.base, (CK_BYTE_PTR)attr->pValue + 3, len);
 	isc_buffer_add(data, len);
 
@@ -617,26 +640,28 @@ pkcs11ecdsa_todns(const dst_key_t *key, isc_buffer_t *data)
 }
 
 static isc_result_t
-pkcs11ecdsa_fromdns(dst_key_t *key, isc_buffer_t *data)
-{
+pkcs11ecdsa_fromdns(dst_key_t *key, isc_buffer_t *data) {
 	pk11_object_t *ec;
-	isc_region_t   r;
-	unsigned int   len;
-	CK_ATTRIBUTE * attr;
+	isc_region_t r;
+	unsigned int len;
+	CK_ATTRIBUTE *attr;
 
 	REQUIRE(key->key_alg == DST_ALG_ECDSA256 ||
 		key->key_alg == DST_ALG_ECDSA384);
 
-	if (key->key_alg == DST_ALG_ECDSA256)
+	if (key->key_alg == DST_ALG_ECDSA256) {
 		len = DNS_KEY_ECDSA256SIZE;
-	else
+	} else {
 		len = DNS_KEY_ECDSA384SIZE;
+	}
 
 	isc_buffer_remainingregion(data, &r);
-	if (r.length == 0)
+	if (r.length == 0) {
 		return (ISC_R_SUCCESS);
-	if (r.length != len)
+	}
+	if (r.length != len) {
 		return (DST_R_INVALIDPUBLICKEY);
+	}
 
 	ec = isc_mem_get(key->mctx, sizeof(*ec));
 	memset(ec, 0, sizeof(*ec));
@@ -646,14 +671,14 @@ pkcs11ecdsa_fromdns(dst_key_t *key, isc_buffer_t *data)
 	attr = ec->repr;
 	attr->type = CKA_EC_PARAMS;
 	if (key->key_alg == DST_ALG_ECDSA256) {
-		attr->pValue =
-			isc_mem_get(key->mctx, sizeof(pk11_ecc_prime256v1));
+		attr->pValue = isc_mem_get(key->mctx,
+					   sizeof(pk11_ecc_prime256v1));
 		memmove(attr->pValue, pk11_ecc_prime256v1,
 			sizeof(pk11_ecc_prime256v1));
 		attr->ulValueLen = sizeof(pk11_ecc_prime256v1);
 	} else {
-		attr->pValue =
-			isc_mem_get(key->mctx, sizeof(pk11_ecc_secp384r1));
+		attr->pValue = isc_mem_get(key->mctx,
+					   sizeof(pk11_ecc_secp384r1));
 		memmove(attr->pValue, pk11_ecc_secp384r1,
 			sizeof(pk11_ecc_secp384r1));
 		attr->ulValueLen = sizeof(pk11_ecc_secp384r1);
@@ -676,17 +701,17 @@ pkcs11ecdsa_fromdns(dst_key_t *key, isc_buffer_t *data)
 }
 
 static isc_result_t
-pkcs11ecdsa_tofile(const dst_key_t *key, const char *directory)
-{
-	isc_result_t   ret;
+pkcs11ecdsa_tofile(const dst_key_t *key, const char *directory) {
+	isc_result_t ret;
 	pk11_object_t *ec;
-	dst_private_t  priv;
+	dst_private_t priv;
 	unsigned char *buf = NULL;
-	unsigned int   i = 0;
-	CK_ATTRIBUTE * attr;
+	unsigned int i = 0;
+	CK_ATTRIBUTE *attr;
 
-	if (key->keydata.pkey == NULL)
+	if (key->keydata.pkey == NULL) {
 		return (DST_R_NULLKEY);
+	}
 
 	if (key->external) {
 		priv.nelements = 0;
@@ -730,27 +755,27 @@ pkcs11ecdsa_tofile(const dst_key_t *key, const char *directory)
 
 static isc_result_t
 pkcs11ecdsa_fetch(dst_key_t *key, const char *engine, const char *label,
-		  dst_key_t *pub)
-{
-	CK_RV		rv;
+		  dst_key_t *pub) {
+	CK_RV rv;
 	CK_OBJECT_CLASS keyClass = CKO_PRIVATE_KEY;
-	CK_KEY_TYPE	keyType = CKK_EC;
-	CK_ATTRIBUTE	searchTemplate[] = {
-		   { CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
-		   { CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
-		   { CKA_TOKEN, &truevalue, (CK_ULONG)sizeof(truevalue) },
-		   { CKA_LABEL, NULL, 0 }
+	CK_KEY_TYPE keyType = CKK_EC;
+	CK_ATTRIBUTE searchTemplate[] = {
+		{ CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
+		{ CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
+		{ CKA_TOKEN, &truevalue, (CK_ULONG)sizeof(truevalue) },
+		{ CKA_LABEL, NULL, 0 }
 	};
-	CK_ULONG	cnt;
-	CK_ATTRIBUTE *	attr;
-	CK_ATTRIBUTE *	pubattr;
-	pk11_object_t * ec;
-	pk11_object_t * pubec;
+	CK_ULONG cnt;
+	CK_ATTRIBUTE *attr;
+	CK_ATTRIBUTE *pubattr;
+	pk11_object_t *ec;
+	pk11_object_t *pubec;
 	pk11_context_t *pk11_ctx = NULL;
-	isc_result_t	ret;
+	isc_result_t ret;
 
-	if (label == NULL)
+	if (label == NULL) {
 		return (DST_R_NOENGINE);
+	}
 
 	ec = key->keydata.pkey;
 	pubec = pub->keydata.pkey;
@@ -779,14 +804,16 @@ pkcs11ecdsa_fetch(dst_key_t *key, const char *engine, const char *label,
 	attr->ulValueLen = pubattr->ulValueLen;
 
 	ret = pk11_parse_uri(ec, label, key->mctx, OP_ECDSA);
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		goto err;
+	}
 
 	pk11_ctx = isc_mem_get(key->mctx, sizeof(*pk11_ctx));
 	ret = pk11_get_session(pk11_ctx, OP_ECDSA, true, false, ec->reqlogon,
 			       NULL, ec->slot);
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		goto err;
+	}
 
 	attr = pk11_attribute_bytype(ec, CKA_LABEL);
 	if (attr == NULL) {
@@ -804,10 +831,12 @@ pkcs11ecdsa_fetch(dst_key_t *key, const char *engine, const char *label,
 		 (pk11_ctx->session, &ec->object, (CK_ULONG)1, &cnt),
 		 DST_R_CRYPTOFAILURE);
 	(void)pkcs_C_FindObjectsFinal(pk11_ctx->session);
-	if (cnt == 0)
+	if (cnt == 0) {
 		DST_RET(ISC_R_NOTFOUND);
-	if (cnt > 1)
+	}
+	if (cnt > 1) {
 		DST_RET(ISC_R_EXISTS);
+	}
 
 	if (engine != NULL) {
 		key->engine = isc_mem_strdup(key->mctx, engine);
@@ -830,30 +859,32 @@ err:
 }
 
 static isc_result_t
-pkcs11ecdsa_parse(dst_key_t *key, isc_lex_t *lexer, dst_key_t *pub)
-{
-	dst_private_t  priv;
-	isc_result_t   ret;
+pkcs11ecdsa_parse(dst_key_t *key, isc_lex_t *lexer, dst_key_t *pub) {
+	dst_private_t priv;
+	isc_result_t ret;
 	pk11_object_t *ec = NULL;
-	CK_ATTRIBUTE * attr, *pattr;
-	isc_mem_t *    mctx = key->mctx;
-	unsigned int   i;
-	const char *   engine = NULL, *label = NULL;
+	CK_ATTRIBUTE *attr, *pattr;
+	isc_mem_t *mctx = key->mctx;
+	unsigned int i;
+	const char *engine = NULL, *label = NULL;
 
 	REQUIRE(key->key_alg == DST_ALG_ECDSA256 ||
 		key->key_alg == DST_ALG_ECDSA384);
 
-	if ((pub == NULL) || (pub->keydata.pkey == NULL))
+	if ((pub == NULL) || (pub->keydata.pkey == NULL)) {
 		DST_RET(DST_R_INVALIDPRIVATEKEY);
+	}
 
 	/* read private key file */
 	ret = dst__privstruct_parse(key, DST_ALG_ECDSA256, lexer, mctx, &priv);
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		return (ret);
+	}
 
 	if (key->external) {
-		if (priv.nelements != 0)
+		if (priv.nelements != 0) {
 			DST_RET(DST_R_INVALIDPRIVATEKEY);
+		}
 
 		key->keydata.pkey = pub->keydata.pkey;
 		pub->keydata.pkey = NULL;
@@ -884,8 +915,9 @@ pkcs11ecdsa_parse(dst_key_t *key, isc_lex_t *lexer, dst_key_t *pub)
 	/* Is this key is stored in a HSM? See if we can fetch it. */
 	if ((label != NULL) || (engine != NULL)) {
 		ret = pkcs11ecdsa_fetch(key, engine, label, pub);
-		if (ret != ISC_R_SUCCESS)
+		if (ret != ISC_R_SUCCESS) {
 			goto err;
+		}
 		dst__privstruct_free(&priv, mctx);
 		memset(&priv, 0, sizeof(priv));
 		return (ret);
@@ -919,10 +951,11 @@ pkcs11ecdsa_parse(dst_key_t *key, isc_lex_t *lexer, dst_key_t *pub)
 
 	dst__privstruct_free(&priv, mctx);
 	memset(&priv, 0, sizeof(priv));
-	if (key->key_alg == DST_ALG_ECDSA256)
+	if (key->key_alg == DST_ALG_ECDSA256) {
 		key->key_size = DNS_KEY_ECDSA256SIZE * 4;
-	else
+	} else {
 		key->key_size = DNS_KEY_ECDSA384SIZE * 4;
+	}
 
 	return (ISC_R_SUCCESS);
 
@@ -935,24 +968,23 @@ err:
 
 static isc_result_t
 pkcs11ecdsa_fromlabel(dst_key_t *key, const char *engine, const char *label,
-		      const char *pin)
-{
-	CK_RV		 rv;
+		      const char *pin) {
+	CK_RV rv;
 	CK_OBJECT_HANDLE hKey = CK_INVALID_HANDLE;
-	CK_OBJECT_CLASS	 keyClass = CKO_PUBLIC_KEY;
-	CK_KEY_TYPE	 keyType = CKK_EC;
-	CK_ATTRIBUTE	 searchTemplate[] = {
-		    { CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
-		    { CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
-		    { CKA_TOKEN, &truevalue, (CK_ULONG)sizeof(truevalue) },
-		    { CKA_LABEL, NULL, 0 }
+	CK_OBJECT_CLASS keyClass = CKO_PUBLIC_KEY;
+	CK_KEY_TYPE keyType = CKK_EC;
+	CK_ATTRIBUTE searchTemplate[] = {
+		{ CKA_CLASS, &keyClass, (CK_ULONG)sizeof(keyClass) },
+		{ CKA_KEY_TYPE, &keyType, (CK_ULONG)sizeof(keyType) },
+		{ CKA_TOKEN, &truevalue, (CK_ULONG)sizeof(truevalue) },
+		{ CKA_LABEL, NULL, 0 }
 	};
-	CK_ULONG	cnt;
-	CK_ATTRIBUTE *	attr;
-	pk11_object_t * ec;
+	CK_ULONG cnt;
+	CK_ATTRIBUTE *attr;
+	pk11_object_t *ec;
 	pk11_context_t *pk11_ctx = NULL;
-	isc_result_t	ret;
-	unsigned int	i;
+	isc_result_t ret;
+	unsigned int i;
 
 	UNUSED(pin);
 
@@ -971,14 +1003,16 @@ pkcs11ecdsa_fromlabel(dst_key_t *key, const char *engine, const char *label,
 	attr[1].type = CKA_EC_POINT;
 
 	ret = pk11_parse_uri(ec, label, key->mctx, OP_ECDSA);
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		goto err;
+	}
 
 	pk11_ctx = isc_mem_get(key->mctx, sizeof(*pk11_ctx));
 	ret = pk11_get_session(pk11_ctx, OP_ECDSA, true, false, ec->reqlogon,
 			       NULL, ec->slot);
-	if (ret != ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS) {
 		goto err;
+	}
 
 	attr = pk11_attribute_bytype(ec, CKA_LABEL);
 	if (attr == NULL) {
@@ -996,10 +1030,12 @@ pkcs11ecdsa_fromlabel(dst_key_t *key, const char *engine, const char *label,
 		 (pk11_ctx->session, &hKey, (CK_ULONG)1, &cnt),
 		 DST_R_CRYPTOFAILURE);
 	(void)pkcs_C_FindObjectsFinal(pk11_ctx->session);
-	if (cnt == 0)
+	if (cnt == 0) {
 		DST_RET(ISC_R_NOTFOUND);
-	if (cnt > 1)
+	}
+	if (cnt > 1) {
 		DST_RET(ISC_R_EXISTS);
+	}
 
 	attr = ec->repr;
 	PK11_RET(pkcs_C_GetAttributeValue, (pk11_ctx->session, hKey, attr, 2),
@@ -1019,20 +1055,23 @@ pkcs11ecdsa_fromlabel(dst_key_t *key, const char *engine, const char *label,
 		 (pk11_ctx->session, &ec->object, (CK_ULONG)1, &cnt),
 		 DST_R_CRYPTOFAILURE);
 	(void)pkcs_C_FindObjectsFinal(pk11_ctx->session);
-	if (cnt == 0)
+	if (cnt == 0) {
 		DST_RET(ISC_R_NOTFOUND);
-	if (cnt > 1)
+	}
+	if (cnt > 1) {
 		DST_RET(ISC_R_EXISTS);
+	}
 
 	if (engine != NULL) {
 		key->engine = isc_mem_strdup(key->mctx, engine);
 	}
 
 	key->label = isc_mem_strdup(key->mctx, label);
-	if (key->key_alg == DST_ALG_ECDSA256)
+	if (key->key_alg == DST_ALG_ECDSA256) {
 		key->key_size = DNS_KEY_ECDSA256SIZE * 4;
-	else
+	} else {
 		key->key_size = DNS_KEY_ECDSA384SIZE * 4;
+	}
 
 	pk11_return_session(pk11_ctx);
 	memset(pk11_ctx, 0, sizeof(*pk11_ctx));
@@ -1074,11 +1113,11 @@ static dst_func_t pkcs11ecdsa_functions = {
 };
 
 isc_result_t
-dst__pkcs11ecdsa_init(dst_func_t **funcp)
-{
+dst__pkcs11ecdsa_init(dst_func_t **funcp) {
 	REQUIRE(funcp != NULL);
-	if (*funcp == NULL)
+	if (*funcp == NULL) {
 		*funcp = &pkcs11ecdsa_functions;
+	}
 	return (ISC_R_SUCCESS);
 }
 
