@@ -10,13 +10,13 @@
  */
 
 /* */
-#ifndef GENERIC_L64_106_H
-#define GENERIC_L64_106_H 1
+#ifndef GENERIC_L32_105_H
+#define GENERIC_L32_105_H 1
 
-typedef struct dns_rdata_l64 {
+typedef struct dns_rdata_l32 {
 	dns_rdatacommon_t common;
-	uint16_t	  pref;
-	unsigned char	  l64[8];
-} dns_rdata_l64_t;
+	uint16_t pref;
+	struct in_addr l32;
+} dns_rdata_l32_t;
 
-#endif /* GENERIC_L64_106_H */
+#endif /* GENERIC_L32_105_H */
