@@ -23,49 +23,54 @@
  * Redefine CHECK here so cppcheck "sees" the define.
  */
 #ifndef CHECK
-#define CHECK(op)						\
-	do { result = (op);					\
-		if (result != ISC_R_SUCCESS) goto cleanup;	\
+#define CHECK(op)                            \
+	do {                                 \
+		result = (op);               \
+		if (result != ISC_R_SUCCESS) \
+			goto cleanup;        \
 	} while (0)
-#endif
+#endif /* ifndef CHECK */
 
 #define RRTYPE_WKS_ATTRIBUTES (0)
 
 static isc_mutex_t wks_lock;
 
-static void init_lock(void) {
-	RUNTIME_CHECK(isc_mutex_init(&wks_lock) == ISC_R_SUCCESS);
+static void
+init_lock(void) {
+	isc_mutex_init(&wks_lock);
 }
 
-static isc_boolean_t
+static bool
 mygetprotobyname(const char *name, long *proto) {
 	struct protoent *pe;
 
 	LOCK(&wks_lock);
 	pe = getprotobyname(name);
-	if (pe != NULL)
+	if (pe != NULL) {
 		*proto = pe->p_proto;
+	}
 	UNLOCK(&wks_lock);
-	return (ISC_TF(pe != NULL));
+	return (pe != NULL);
 }
 
-static isc_boolean_t
+static bool
 mygetservbyname(const char *name, const char *proto, long *port) {
 	struct servent *se;
 
 	LOCK(&wks_lock);
 	se = getservbyname(name, proto);
-	if (se != NULL)
+	if (se != NULL) {
 		*port = ntohs(se->s_port);
+	}
 	UNLOCK(&wks_lock);
-	return (ISC_TF(se != NULL));
+	return (se != NULL);
 }
 
 #ifdef _WIN32
 #include <windows.h>
 #include <winsock2.h>
 #include <ws2tcpip.h>
-#endif
+#endif /* ifdef _WIN32 */
 
 static inline isc_result_t
 fromtext_in_wks(ARGS_FROMTEXT) {
@@ -75,7 +80,7 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 	struct in_addr addr;
 	char *e;
 	long proto;
-	unsigned char bm[8*1024]; /* 64k bits */
+	unsigned char bm[8 * 1024]; /* 64k bits */
 	long port;
 	long maxport = -1;
 	const char *ps = NULL;
@@ -91,6 +96,7 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 	UNUSED(origin);
 	UNUSED(options);
 	UNUSED(rdclass);
+	UNUSED(callbacks);
 
 	RUNTIME_CHECK(isc_once_do(&once, init_lock) == ISC_R_SUCCESS);
 
@@ -102,23 +108,26 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 
 		wVersionRequested = MAKEWORD(2, 0);
 
-		err = WSAStartup(wVersionRequested, &wsaData );
-		if (err != 0)
+		err = WSAStartup(wVersionRequested, &wsaData);
+		if (err != 0) {
 			return (ISC_R_FAILURE);
+		}
 	}
-#endif
+#endif /* ifdef _WIN32 */
 
 	/*
 	 * IPv4 dotted quad.
 	 */
 	CHECK(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      ISC_FALSE));
+				     false));
 
 	isc_buffer_availableregion(target, &region);
-	if (getquad(DNS_AS_STR(token), &addr, lexer, callbacks) != 1)
+	if (inet_pton(AF_INET, DNS_AS_STR(token), &addr) != 1) {
 		CHECKTOK(DNS_R_BADDOTTEDQUAD);
-	if (region.length < 4)
+	}
+	if (region.length < 4) {
 		return (ISC_R_NOSPACE);
+	}
 	memmove(region.base, &addr, 4);
 	isc_buffer_add(target, 4);
 
@@ -126,51 +135,58 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 	 * Protocol.
 	 */
 	CHECK(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      ISC_FALSE));
+				     false));
 
 	proto = strtol(DNS_AS_STR(token), &e, 10);
-	if (*e == 0)
-		;
-	else if (!mygetprotobyname(DNS_AS_STR(token), &proto))
+	if (*e == 0) {
+	} else if (!mygetprotobyname(DNS_AS_STR(token), &proto)) {
 		CHECKTOK(DNS_R_UNKNOWNPROTO);
+	}
 
-	if (proto < 0 || proto > 0xff)
+	if (proto < 0 || proto > 0xff) {
 		CHECKTOK(ISC_R_RANGE);
+	}
 
-	if (proto == IPPROTO_TCP)
+	if (proto == IPPROTO_TCP) {
 		ps = "tcp";
-	else if (proto == IPPROTO_UDP)
+	} else if (proto == IPPROTO_UDP) {
 		ps = "udp";
+	}
 
 	CHECK(uint8_tobuffer(proto, target));
 
 	memset(bm, 0, sizeof(bm));
 	do {
 		CHECK(isc_lex_getmastertoken(lexer, &token,
-					      isc_tokentype_string, ISC_TRUE));
-		if (token.type != isc_tokentype_string)
+					     isc_tokentype_string, true));
+		if (token.type != isc_tokentype_string) {
 			break;
+		}
 
 		/*
 		 * Lowercase the service string as some getservbyname() are
 		 * case sensitive and the database is usually in lowercase.
 		 */
-		strncpy(service, DNS_AS_STR(token), sizeof(service));
-		service[sizeof(service)-1] = '\0';
-		for (i = strlen(service) - 1; i >= 0; i--)
-			if (isupper(service[i]&0xff))
-				service[i] = tolower(service[i]&0xff);
+		strlcpy(service, DNS_AS_STR(token), sizeof(service));
+		for (i = strlen(service) - 1; i >= 0; i--) {
+			if (isupper(service[i] & 0xff)) {
+				service[i] = tolower(service[i] & 0xff);
+			}
+		}
 
 		port = strtol(DNS_AS_STR(token), &e, 10);
-		if (*e == 0)
-			;
-		else if (!mygetservbyname(service, ps, &port) &&
-			 !mygetservbyname(DNS_AS_STR(token), ps, &port))
+		if (*e == 0) {
+		} else if (!mygetservbyname(service, ps, &port) &&
+			   !mygetservbyname(DNS_AS_STR(token), ps, &port))
+		{
 			CHECKTOK(DNS_R_UNKNOWNSERVICE);
-		if (port < 0 || port > 0xffff)
+		}
+		if (port < 0 || port > 0xffff) {
 			CHECKTOK(ISC_R_RANGE);
-		if (port > maxport)
+		}
+		if (port > maxport) {
 			maxport = port;
+		}
 		bm[port / 8] |= (0x80 >> (port % 8));
 	} while (1);
 
@@ -182,10 +198,10 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 	n = (maxport + 8) / 8;
 	result = mem_tobuffer(target, bm, n);
 
- cleanup:
+cleanup:
 #ifdef _WIN32
 	WSACleanup();
-#endif
+#endif /* ifdef _WIN32 */
 
 	return (result);
 }
@@ -213,16 +229,20 @@ totext_in_wks(ARGS_TOTEXT) {
 	RETERR(str_totext(buf, target));
 	isc_region_consume(&sr, 1);
 
-	INSIST(sr.length <= 8*1024);
+	INSIST(sr.length <= 8 * 1024);
 	for (i = 0; i < sr.length; i++) {
-		if (sr.base[i] != 0)
-			for (j = 0; j < 8; j++)
+		if (sr.base[i] != 0) {
+			for (j = 0; j < 8; j++) {
 				if ((sr.base[i] & (0x80 >> j)) != 0) {
-					snprintf(buf, sizeof(buf),
-						 "%u", i * 8 + j);
-					RETERR(str_totext(" ", target));
-					RETERR(str_totext(buf, target));
+					{
+						snprintf(buf, sizeof(buf), "%u",
+							 i * 8 + j);
+						RETERR(str_totext(" ", target));
+						RETERR(str_totext(buf, target));
+					}
 				}
+			}
+		}
 	}
 
 	return (ISC_R_SUCCESS);
@@ -244,12 +264,15 @@ fromwire_in_wks(ARGS_FROMWIRE) {
 	isc_buffer_activeregion(source, &sr);
 	isc_buffer_availableregion(target, &tr);
 
-	if (sr.length < 5)
+	if (sr.length < 5) {
 		return (ISC_R_UNEXPECTEDEND);
-	if (sr.length > 8 * 1024 + 5)
+	}
+	if (sr.length > 8 * 1024 + 5) {
 		return (DNS_R_EXTRADATA);
-	if (tr.length < sr.length)
+	}
+	if (tr.length < sr.length) {
 		return (ISC_R_NOSPACE);
+	}
 
 	memmove(tr.base, sr.base, sr.length);
 	isc_buffer_add(target, sr.length);
@@ -292,15 +315,15 @@ compare_in_wks(ARGS_COMPARE) {
 static inline isc_result_t
 fromstruct_in_wks(ARGS_FROMSTRUCT) {
 	dns_rdata_in_wks_t *wks = source;
-	isc_uint32_t a;
+	uint32_t a;
 
 	REQUIRE(type == dns_rdatatype_wks);
 	REQUIRE(rdclass == dns_rdataclass_in);
-	REQUIRE(source != NULL);
+	REQUIRE(wks != NULL);
 	REQUIRE(wks->common.rdtype == type);
 	REQUIRE(wks->common.rdclass == rdclass);
-	REQUIRE((wks->map != NULL && wks->map_len <= 8*1024) ||
-		 wks->map_len == 0);
+	REQUIRE((wks->map != NULL && wks->map_len <= 8 * 1024) ||
+		wks->map_len == 0);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -314,9 +337,10 @@ fromstruct_in_wks(ARGS_FROMSTRUCT) {
 static inline isc_result_t
 tostruct_in_wks(ARGS_TOSTRUCT) {
 	dns_rdata_in_wks_t *wks = target;
-	isc_uint32_t n;
+	uint32_t n;
 	isc_region_t region;
 
+	REQUIRE(wks != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_wks);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 	REQUIRE(rdata->length != 0);
@@ -333,8 +357,9 @@ tostruct_in_wks(ARGS_TOSTRUCT) {
 	isc_region_consume(&region, 1);
 	wks->map_len = region.length;
 	wks->map = mem_maybedup(mctx, region.base, region.length);
-	if (wks->map == NULL)
+	if (wks->map == NULL) {
 		return (ISC_R_NOMEMORY);
+	}
 	wks->mctx = mctx;
 	return (ISC_R_SUCCESS);
 }
@@ -343,15 +368,17 @@ static inline void
 freestruct_in_wks(ARGS_FREESTRUCT) {
 	dns_rdata_in_wks_t *wks = source;
 
-	REQUIRE(source != NULL);
+	REQUIRE(wks != NULL);
 	REQUIRE(wks->common.rdtype == dns_rdatatype_wks);
 	REQUIRE(wks->common.rdclass == dns_rdataclass_in);
 
-	if (wks->mctx == NULL)
+	if (wks->mctx == NULL) {
 		return;
+	}
 
-	if (wks->map != NULL)
+	if (wks->map != NULL) {
 		isc_mem_free(wks->mctx, wks->map);
+	}
 	wks->mctx = NULL;
 }
 
@@ -379,9 +406,8 @@ digest_in_wks(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline isc_boolean_t
+static inline bool
 checkowner_in_wks(ARGS_CHECKOWNER) {
-
 	REQUIRE(type == dns_rdatatype_wks);
 	REQUIRE(rdclass == dns_rdataclass_in);
 
@@ -391,9 +417,8 @@ checkowner_in_wks(ARGS_CHECKOWNER) {
 	return (dns_name_ishostname(name, wildcard));
 }
 
-static inline isc_boolean_t
+static inline bool
 checknames_in_wks(ARGS_CHECKNAMES) {
-
 	REQUIRE(rdata->type == dns_rdatatype_wks);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 
@@ -401,7 +426,7 @@ checknames_in_wks(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static inline int
@@ -409,4 +434,4 @@ casecompare_in_wks(ARGS_COMPARE) {
 	return (compare_in_wks(rdata1, rdata2));
 }
 
-#endif	/* RDATA_IN_1_WKS_11_C */
+#endif /* RDATA_IN_1_WKS_11_C */
