@@ -28,7 +28,7 @@
 
 #ifdef HAVE_ZLIB
 #include <zlib.h>
-#endif
+#endif /* ifdef HAVE_ZLIB */
 
 /*%
  * TODO:
@@ -38,43 +38,43 @@
  *     page and close the client.
  */
 
-#define MSHUTTINGDOWN(cm) ((cm->flags & ISC_HTTPDMGR_FLAGSHUTTINGDOWN) != 0)
+#define MSHUTTINGDOWN(cm)    ((cm->flags & ISC_HTTPDMGR_FLAGSHUTTINGDOWN) != 0)
 #define MSETSHUTTINGDOWN(cm) (cm->flags |= ISC_HTTPDMGR_FLAGSHUTTINGDOWN)
 
-#define HTTP_RECVLEN 1024
-#define HTTP_SENDGROW 1024
+#define HTTP_RECVLEN	 1024
+#define HTTP_SENDGROW	 1024
 #define HTTP_SEND_MAXLEN 10240
 
-#define HTTPD_CLOSE 0x0001     /* Got a Connection: close header */
-#define HTTPD_FOUNDHOST 0x0002 /* Got a Host: header */
-#define HTTPD_KEEPALIVE 0x0004 /* Got a Connection: Keep-Alive */
+#define HTTPD_CLOSE	     0x0001 /* Got a Connection: close header */
+#define HTTPD_FOUNDHOST	     0x0002 /* Got a Host: header */
+#define HTTPD_KEEPALIVE	     0x0004 /* Got a Connection: Keep-Alive */
 #define HTTPD_ACCEPT_DEFLATE 0x0008
 
-#define HTTPD_MAGIC ISC_MAGIC('H', 't', 'p', 'd')
+#define HTTPD_MAGIC    ISC_MAGIC('H', 't', 'p', 'd')
 #define VALID_HTTPD(m) ISC_MAGIC_VALID(m, HTTPD_MAGIC)
 
-#define HTTPDMGR_MAGIC ISC_MAGIC('H', 'p', 'd', 'm')
+#define HTTPDMGR_MAGIC	  ISC_MAGIC('H', 'p', 'd', 'm')
 #define VALID_HTTPDMGR(m) ISC_MAGIC_VALID(m, HTTPDMGR_MAGIC)
 
 /*% http client */
 struct isc_httpd {
-	unsigned int	magic; /* HTTPD_MAGIC */
-	isc_refcount_t	references;
+	unsigned int magic; /* HTTPD_MAGIC */
+	isc_refcount_t references;
 	isc_httpdmgr_t *mgr; /*%< our parent */
 	ISC_LINK(isc_httpd_t) link;
-	unsigned int  state;
+	unsigned int state;
 	isc_socket_t *sock;
 
 	/*%
 	 * Received data state.
 	 */
-	char	     recvbuf[HTTP_RECVLEN]; /*%< receive buffer */
-	uint32_t     recvlen;		    /*%< length recv'd */
-	char *	     headers;		    /*%< set in process_request() */
+	char recvbuf[HTTP_RECVLEN]; /*%< receive buffer */
+	uint32_t recvlen;	    /*%< length recv'd */
+	char *headers;		    /*%< set in process_request() */
 	unsigned int method;
-	char *	     url;
-	char *	     querystring;
-	char *	     protocol;
+	char *url;
+	char *querystring;
+	char *protocol;
 
 	/*
 	 * Flags on the httpd client.
@@ -107,30 +107,30 @@ struct isc_httpd {
 	 * compressed HTTP data, if compression is used.
 	 *
 	 */
-	isc_buffer_t  headerbuffer;
-	isc_buffer_t  compbuffer;
+	isc_buffer_t headerbuffer;
+	isc_buffer_t compbuffer;
 	isc_buffer_t *sendbuffer;
 
-	const char *	 mimetype;
-	unsigned int	 retcode;
-	const char *	 retmsg;
-	isc_buffer_t	 bodybuffer;
+	const char *mimetype;
+	unsigned int retcode;
+	const char *retmsg;
+	isc_buffer_t bodybuffer;
 	isc_httpdfree_t *freecb;
-	void *		 freecb_arg;
+	void *freecb_arg;
 };
 
 /*% lightweight socket manager for httpd output */
 struct isc_httpdmgr {
-	unsigned int	magic; /* HTTPDMGR_MAGIC */
-	isc_refcount_t	references;
-	isc_mem_t *	mctx;
-	isc_socket_t *	sock; /*%< listening socket */
-	isc_task_t *	task; /*%< owning task */
+	unsigned int magic; /* HTTPDMGR_MAGIC */
+	isc_refcount_t references;
+	isc_mem_t *mctx;
+	isc_socket_t *sock; /*%< listening socket */
+	isc_task_t *task;   /*%< owning task */
 	isc_timermgr_t *timermgr;
 
-	isc_httpdclientok_t * client_ok; /*%< client validator */
+	isc_httpdclientok_t *client_ok;	 /*%< client validator */
 	isc_httpdondestroy_t *ondestroy; /*%< cleanup callback */
-	void *		      cb_arg;	 /*%< argument for the above */
+	void *cb_arg;			 /*%< argument for the above */
 
 	unsigned int flags;
 	ISC_LIST(isc_httpd_t) running; /*%< running clients */
@@ -146,8 +146,8 @@ struct isc_httpdmgr {
  * HTTP methods.
  */
 #define ISC_HTTPD_METHODUNKNOWN 0
-#define ISC_HTTPD_METHODGET 1
-#define ISC_HTTPD_METHODPOST 2
+#define ISC_HTTPD_METHODGET	1
+#define ISC_HTTPD_METHODPOST	2
 
 /*%
  * Client states.
@@ -178,23 +178,23 @@ struct isc_httpdmgr {
  *	At any time -> RECV on error.  If RECV fails, the client will
  *	self-destroy, closing the socket and freeing memory.
  */
-#define ISC_HTTPD_STATEIDLE 0
-#define ISC_HTTPD_STATERECV 1
+#define ISC_HTTPD_STATEIDLE	0
+#define ISC_HTTPD_STATERECV	1
 #define ISC_HTTPD_STATERECVDONE 2
-#define ISC_HTTPD_STATESEND 3
+#define ISC_HTTPD_STATESEND	3
 #define ISC_HTTPD_STATESENDDONE 4
 
-#define ISC_HTTPD_ISRECV(c) ((c)->state == ISC_HTTPD_STATERECV)
+#define ISC_HTTPD_ISRECV(c)	((c)->state == ISC_HTTPD_STATERECV)
 #define ISC_HTTPD_ISRECVDONE(c) ((c)->state == ISC_HTTPD_STATERECVDONE)
-#define ISC_HTTPD_ISSEND(c) ((c)->state == ISC_HTTPD_STATESEND)
+#define ISC_HTTPD_ISSEND(c)	((c)->state == ISC_HTTPD_STATESEND)
 #define ISC_HTTPD_ISSENDDONE(c) ((c)->state == ISC_HTTPD_STATESENDDONE)
 
 /*%
  * Overall magic test that means we're not idle.
  */
-#define ISC_HTTPD_SETRECV(c) ((c)->state = ISC_HTTPD_STATERECV)
+#define ISC_HTTPD_SETRECV(c)	 ((c)->state = ISC_HTTPD_STATERECV)
 #define ISC_HTTPD_SETRECVDONE(c) ((c)->state = ISC_HTTPD_STATERECVDONE)
-#define ISC_HTTPD_SETSEND(c) ((c)->state = ISC_HTTPD_STATESEND)
+#define ISC_HTTPD_SETSEND(c)	 ((c)->state = ISC_HTTPD_STATESEND)
 #define ISC_HTTPD_SETSENDDONE(c) ((c)->state = ISC_HTTPD_STATESENDDONE)
 
 static void
@@ -232,16 +232,14 @@ static void
 isc_httpdmgr_detach(isc_httpdmgr_t **);
 
 static void
-maybe_destroy_httpd(isc_httpd_t *httpd)
-{
+maybe_destroy_httpd(isc_httpd_t *httpd) {
 	if (isc_refcount_decrement(&httpd->references) == 1) {
 		destroy_httpd(httpd);
 	}
 }
 
 static inline void
-free_buffer(isc_mem_t *mctx, isc_buffer_t *buffer)
-{
+free_buffer(isc_mem_t *mctx, isc_buffer_t *buffer) {
 	isc_region_t r;
 
 	isc_buffer_region(buffer, &r);
@@ -251,8 +249,7 @@ free_buffer(isc_mem_t *mctx, isc_buffer_t *buffer)
 }
 
 static void
-destroy_httpd(isc_httpd_t *httpd)
-{
+destroy_httpd(isc_httpd_t *httpd) {
 	isc_httpdmgr_t *httpdmgr;
 
 	REQUIRE(VALID_HTTPD(httpd));
@@ -288,8 +285,7 @@ destroy_httpd(isc_httpd_t *httpd)
 }
 
 static inline isc_result_t
-httpdmgr_socket_accept(isc_task_t *task, isc_httpdmgr_t *httpdmgr)
-{
+httpdmgr_socket_accept(isc_task_t *task, isc_httpdmgr_t *httpdmgr) {
 	isc_result_t result = ISC_R_SUCCESS;
 
 	/* decremented in isc_httpd_accept */
@@ -303,8 +299,7 @@ httpdmgr_socket_accept(isc_task_t *task, isc_httpdmgr_t *httpdmgr)
 }
 
 static inline void
-httpd_socket_recv(isc_httpd_t *httpd, isc_region_t *region, isc_task_t *task)
-{
+httpd_socket_recv(isc_httpd_t *httpd, isc_region_t *region, isc_task_t *task) {
 	isc_result_t result = ISC_R_SUCCESS;
 
 	/* decremented in isc_httpd_recvdone */
@@ -317,8 +312,7 @@ httpd_socket_recv(isc_httpd_t *httpd, isc_region_t *region, isc_task_t *task)
 }
 
 static inline void
-httpd_socket_send(isc_httpd_t *httpd, isc_region_t *region, isc_task_t *task)
-{
+httpd_socket_send(isc_httpd_t *httpd, isc_region_t *region, isc_task_t *task) {
 	isc_result_t result = ISC_R_SUCCESS;
 
 	/* decremented in isc_httpd_senddone */
@@ -332,11 +326,10 @@ httpd_socket_send(isc_httpd_t *httpd, isc_region_t *region, isc_task_t *task)
 
 isc_result_t
 isc_httpdmgr_create(isc_mem_t *mctx, isc_socket_t *sock, isc_task_t *task,
-		    isc_httpdclientok_t * client_ok,
+		    isc_httpdclientok_t *client_ok,
 		    isc_httpdondestroy_t *ondestroy, void *cb_arg,
-		    isc_timermgr_t *tmgr, isc_httpdmgr_t **httpdmgrp)
-{
-	isc_result_t	result;
+		    isc_timermgr_t *tmgr, isc_httpdmgr_t **httpdmgrp) {
+	isc_result_t result;
 	isc_httpdmgr_t *httpdmgr;
 
 	REQUIRE(mctx != NULL);
@@ -348,7 +341,7 @@ isc_httpdmgr_create(isc_mem_t *mctx, isc_socket_t *sock, isc_task_t *task,
 	httpdmgr = isc_mem_get(mctx, sizeof(isc_httpdmgr_t));
 
 	*httpdmgr = (isc_httpdmgr_t){ .timermgr = tmgr, /* XXXMLG no attach
-							   function? */
+							 * function? */
 				      .client_ok = client_ok,
 				      .ondestroy = ondestroy,
 				      .cb_arg = cb_arg,
@@ -399,8 +392,7 @@ cleanup:
 }
 
 static void
-isc_httpdmgr_attach(isc_httpdmgr_t *source, isc_httpdmgr_t **targetp)
-{
+isc_httpdmgr_attach(isc_httpdmgr_t *source, isc_httpdmgr_t **targetp) {
 	REQUIRE(VALID_HTTPDMGR(source));
 	REQUIRE(targetp != NULL && *targetp == NULL);
 
@@ -410,8 +402,7 @@ isc_httpdmgr_attach(isc_httpdmgr_t *source, isc_httpdmgr_t **targetp)
 }
 
 static void
-isc_httpdmgr_detach(isc_httpdmgr_t **httpdmgrp)
-{
+isc_httpdmgr_detach(isc_httpdmgr_t **httpdmgrp) {
 	REQUIRE(httpdmgrp != NULL && VALID_HTTPDMGR(*httpdmgrp));
 	isc_httpdmgr_t *httpdmgr = *httpdmgrp;
 	*httpdmgrp = NULL;
@@ -420,16 +411,14 @@ isc_httpdmgr_detach(isc_httpdmgr_t **httpdmgrp)
 }
 
 static void
-maybe_destroy_httpdmgr(isc_httpdmgr_t *httpdmgr)
-{
+maybe_destroy_httpdmgr(isc_httpdmgr_t *httpdmgr) {
 	if (isc_refcount_decrement(&httpdmgr->references) == 1) {
 		destroy_httpdmgr(httpdmgr);
 	}
 }
 
 static void
-destroy_httpdmgr(isc_httpdmgr_t *httpdmgr)
-{
+destroy_httpdmgr(isc_httpdmgr_t *httpdmgr) {
 	isc_httpdurl_t *url;
 
 	isc_refcount_destroy(&httpdmgr->references);
@@ -475,9 +464,8 @@ destroy_httpdmgr(isc_httpdmgr_t *httpdmgr)
  */
 static bool
 have_header(isc_httpd_t *httpd, const char *header, const char *value,
-	    const char *eov)
-{
-	char * cr, *nl, *h;
+	    const char *eov) {
+	char *cr, *nl, *h;
 	size_t hlen, vlen = 0;
 
 	h = httpd->headers;
@@ -493,55 +481,66 @@ have_header(isc_httpd_t *httpd, const char *header, const char *value,
 			 * Skip to next line;
 			 */
 			cr = strchr(h, '\r');
-			if (cr != NULL && cr[1] == '\n')
+			if (cr != NULL && cr[1] == '\n') {
 				cr++;
+			}
 			nl = strchr(h, '\n');
 
 			/* last header? */
 			h = cr;
-			if (h == NULL || (nl != NULL && nl < h))
+			if (h == NULL || (nl != NULL && nl < h)) {
 				h = nl;
-			if (h == NULL)
+			}
+			if (h == NULL) {
 				return (false);
+			}
 			h++;
 			continue;
 		}
 
-		if (value == NULL)
+		if (value == NULL) {
 			return (true);
+		}
 
 		/*
 		 * Skip optional leading white space.
 		 */
 		h += hlen;
-		while (*h == ' ' || *h == '\t')
+		while (*h == ' ' || *h == '\t') {
 			h++;
+		}
 		/*
 		 * Terminate token search on NULL or EOL.
 		 */
 		while (*h != 0 && *h != '\r' && *h != '\n') {
-			if (strncasecmp(h, value, vlen) == 0)
-				if (strchr(eov, h[vlen]) != NULL)
+			if (strncasecmp(h, value, vlen) == 0) {
+				if (strchr(eov, h[vlen]) != NULL) {
 					return (true);
+					/*
+					 * Skip to next token.
+					 */
+				}
+			}
 			/*
 			 * Skip to next token.
 			 */
 			h += strcspn(h, eov);
-			if (h[0] == '\r' && h[1] == '\n')
+			if (h[0] == '\r' && h[1] == '\n') {
 				h++;
-			if (h[0] != 0)
+			}
+			if (h[0] != 0) {
 				h++;
+			}
 		}
 		return (false);
 	}
 }
 
 static isc_result_t
-process_request(isc_httpd_t *httpd, int length)
-{
+process_request(isc_httpd_t *httpd, int length) {
 	char *s;
 	char *p;
-	int   delim;
+	int delim;
 
 	httpd->recvlen += length;
 
@@ -558,8 +557,9 @@ process_request(isc_httpd_t *httpd, int length)
 		s = strstr(httpd->recvbuf, "\n\n");
 		delim = 1;
 	}
-	if (s == NULL)
+	if (s == NULL) {
 		return (ISC_R_NOTFOUND);
+	}
 
 	/*
 	 * NUL terminate request at the blank line.
@@ -590,11 +590,15 @@ process_request(isc_httpd_t *httpd, int length)
 	s = p;
 	while (LENGTHOK(s) && BUFLENOK(s) &&
 	       (*s != '\n' && *s != '\r' && *s != '\0' && *s != ' '))
+	{
 		s++;
-	if (!LENGTHOK(s))
+	}
+	if (!LENGTHOK(s)) {
 		return (ISC_R_NOTFOUND);
-	if (!BUFLENOK(s))
+	}
+	if (!BUFLENOK(s)) {
 		return (ISC_R_NOMEMORY);
+	}
 	*s = 0;
 
 	/*
@@ -602,20 +606,25 @@ process_request(isc_httpd_t *httpd, int length)
 	 */
 	if ((strncmp(p, "http:/", 6) == 0) || (strncmp(p, "https:/", 7) == 0)) {
 		/* Skip first / */
-		while (*p != '/' && *p != 0)
+		while (*p != '/' && *p != 0) {
 			p++;
-		if (*p == 0)
+		}
+		if (*p == 0) {
 			return (ISC_R_RANGE);
+		}
 		p++;
 		/* Skip second / */
-		while (*p != '/' && *p != 0)
+		while (*p != '/' && *p != 0) {
 			p++;
-		if (*p == 0)
+		}
+		if (*p == 0) {
 			return (ISC_R_RANGE);
+		}
 		p++;
 		/* Find third / */
-		while (*p != '/' && *p != 0)
+		while (*p != '/' && *p != 0) {
 			p++;
+		}
 		if (*p == 0) {
 			p--;
 			*p = '/';
@@ -641,64 +650,75 @@ process_request(isc_httpd_t *httpd, int length)
 	 * HTTP/1.0 or HTTP/1.1 for now.
 	 */
 	while (LENGTHOK(s) && BUFLENOK(s) &&
-	       (*s != '\n' && *s != '\r' && *s != '\0'))
+	       (*s != '\n' && *s != '\r' && *s != '\0')) {
 		s++;
-	if (!LENGTHOK(s))
+	}
+	if (!LENGTHOK(s)) {
 		return (ISC_R_NOTFOUND);
-	if (!BUFLENOK(s))
+	}
+	if (!BUFLENOK(s)) {
 		return (ISC_R_NOMEMORY);
+	}
 	/*
 	 * Check that we have the expected eol delimiter.
 	 */
-	if (strncmp(s, delim == 1 ? "\n" : "\r\n", delim) != 0)
+	if (strncmp(s, delim == 1 ? "\n" : "\r\n", delim) != 0) {
 		return (ISC_R_RANGE);
+	}
 	*s = 0;
 	if ((strncmp(p, "HTTP/1.0", 8) != 0) &&
-	    (strncmp(p, "HTTP/1.1", 8) != 0))
+	    (strncmp(p, "HTTP/1.1", 8) != 0)) {
 		return (ISC_R_RANGE);
+	}
 	httpd->protocol = p;
 	p = s + delim; /* skip past eol */
 	s = p;
 
 	httpd->headers = s;
 
-	if (have_header(httpd, "Connection:", "close", ", \t\r\n"))
+	if (have_header(httpd, "Connection:", "close", ", \t\r\n")) {
 		httpd->flags |= HTTPD_CLOSE;
+	}
 
-	if (have_header(httpd, "Host:", NULL, NULL))
+	if (have_header(httpd, "Host:", NULL, NULL)) {
 		httpd->flags |= HTTPD_FOUNDHOST;
+	}
 
 	if (strncmp(httpd->protocol, "HTTP/1.0", 8) == 0) {
 		if (have_header(httpd, "Connection:", "Keep-Alive", ", \t\r\n"))
+		{
 			httpd->flags |= HTTPD_KEEPALIVE;
-		else
+		} else {
 			httpd->flags |= HTTPD_CLOSE;
+		}
 	}
 
 	/*
 	 * Check for Accept-Encoding:
 	 */
 #ifdef HAVE_ZLIB
-	if (have_header(httpd, "Accept-Encoding:", "deflate", ";, \t\r\n"))
+	if (have_header(httpd, "Accept-Encoding:", "deflate", ";, \t\r\n")) {
 		httpd->flags |= HTTPD_ACCEPT_DEFLATE;
-#endif
+	}
+#endif /* ifdef HAVE_ZLIB */
 
 	/*
 	 * Standards compliance hooks here.
 	 */
 	if (strcmp(httpd->protocol, "HTTP/1.1") == 0 &&
 	    ((httpd->flags & HTTPD_FOUNDHOST) == 0))
+	{
 		return (ISC_R_RANGE);
+	}
 
 	return (ISC_R_SUCCESS);
 }
 
 static void
 isc_httpd_create(isc_httpdmgr_t *httpdmgr, isc_socket_t *sock,
-		 isc_httpd_t **httpdp)
-{
+		 isc_httpd_t **httpdp) {
 	isc_httpd_t *httpd;
-	char *	     headerdata;
+	char *headerdata;
 
 	REQUIRE(VALID_HTTPDMGR(httpdmgr));
 	REQUIRE(httpdp != NULL && *httpdp == NULL);
@@ -732,13 +752,12 @@ isc_httpd_create(isc_httpdmgr_t *httpdmgr, isc_socket_t *sock,
 }
 
 static void
-isc_httpd_accept(isc_task_t *task, isc_event_t *ev)
-{
-	isc_httpdmgr_t *	httpdmgr = ev->ev_arg;
-	isc_httpd_t *		httpd = NULL;
-	isc_region_t		r;
+isc_httpd_accept(isc_task_t *task, isc_event_t *ev) {
+	isc_httpdmgr_t *httpdmgr = ev->ev_arg;
+	isc_httpd_t *httpd = NULL;
+	isc_region_t r;
 	isc_socket_newconnev_t *nev = (isc_socket_newconnev_t *)ev;
-	isc_sockaddr_t		peeraddr;
+	isc_sockaddr_t peeraddr;
 
 	REQUIRE(VALID_HTTPDMGR(httpdmgr));
 
@@ -758,7 +777,8 @@ isc_httpd_accept(isc_task_t *task, isc_event_t *ev)
 
 	(void)isc_socket_getpeername(nev->newsocket, &peeraddr);
 	if (httpdmgr->client_ok != NULL &&
-	    !(httpdmgr->client_ok)(&peeraddr, httpdmgr->cb_arg)) {
+	    !(httpdmgr->client_ok)(&peeraddr, httpdmgr->cb_arg))
+	{
 		isc_socket_detach(&nev->newsocket);
 		goto requeue;
 	}
@@ -788,8 +808,7 @@ static isc_result_t
 render_404(const char *url, isc_httpdurl_t *urlinfo, const char *querystring,
 	   const char *headers, void *arg, unsigned int *retcode,
 	   const char **retmsg, const char **mimetype, isc_buffer_t *b,
-	   isc_httpdfree_t **freecb, void **freecb_args)
-{
+	   isc_httpdfree_t **freecb, void **freecb_args) {
 	static char msg[] = "No such URL.\r\n";
 
 	UNUSED(url);
@@ -813,8 +832,7 @@ static isc_result_t
 render_500(const char *url, isc_httpdurl_t *urlinfo, const char *querystring,
 	   const char *headers, void *arg, unsigned int *retcode,
 	   const char **retmsg, const char **mimetype, isc_buffer_t *b,
-	   isc_httpdfree_t **freecb, void **freecb_args)
-{
+	   isc_httpdfree_t **freecb, void **freecb_args) {
 	static char msg[] = "Internal server failure.\r\n";
 
 	UNUSED(url);
@@ -847,9 +865,8 @@ render_500(const char *url, isc_httpdurl_t *urlinfo, const char *querystring,
  *\li	#ISC_R_NOMEMORY		-- not enough memory to extend buffer
  */
 static isc_result_t
-alloc_compspace(isc_httpd_t *httpd, unsigned int size)
-{
-	char *	     newspace;
+alloc_compspace(isc_httpd_t *httpd, unsigned int size) {
+	char *newspace;
 	isc_region_t r;
 
 	isc_buffer_region(&httpd->compbuffer, &r);
@@ -881,18 +898,17 @@ alloc_compspace(isc_httpd_t *httpd, unsigned int size)
  *			     data would be larger than input data
  */
 static isc_result_t
-isc_httpd_compress(isc_httpd_t *httpd)
-{
-	z_stream     zstr;
+isc_httpd_compress(isc_httpd_t *httpd) {
+	z_stream zstr;
 	isc_region_t r;
 	isc_result_t result;
-	int	     ret;
-	int	     inputlen;
+	int ret;
+	int inputlen;
 
 	inputlen = isc_buffer_usedlength(&httpd->bodybuffer);
 	result = alloc_compspace(httpd, inputlen);
 	if (result != ISC_R_SUCCESS) {
-		return result;
+		return (result);
 	}
 	isc_buffer_region(&httpd->compbuffer, &r);
 
@@ -919,20 +935,19 @@ isc_httpd_compress(isc_httpd_t *httpd)
 		return (ISC_R_FAILURE);
 	}
 }
-#endif
+#endif /* ifdef HAVE_ZLIB */
 
 static void
-isc_httpd_recvdone(isc_task_t *task, isc_event_t *ev)
-{
-	isc_result_t	   result;
-	isc_httpd_t *	   httpd = ev->ev_arg;
+isc_httpd_recvdone(isc_task_t *task, isc_event_t *ev) {
+	isc_result_t result;
+	isc_httpd_t *httpd = ev->ev_arg;
 	isc_socketevent_t *sev = (isc_socketevent_t *)ev;
-	isc_buffer_t *	   databuffer;
-	isc_httpdurl_t *   url;
-	isc_time_t	   now;
-	isc_region_t	   r;
-	bool		   is_compressed = false;
-	char		   datebuf[ISC_FORMATHTTPTIMESTAMP_SIZE];
+	isc_buffer_t *databuffer;
+	isc_httpdurl_t *url;
+	isc_time_t now;
+	isc_region_t r;
+	bool is_compressed = false;
+	char datebuf[ISC_FORMATHTTPTIMESTAMP_SIZE];
 
 	REQUIRE(VALID_HTTPD(httpd));
 
@@ -968,8 +983,9 @@ isc_httpd_recvdone(isc_task_t *task, isc_event_t *ev)
 	LOCK(&httpd->mgr->lock);
 	url = ISC_LIST_HEAD(httpd->mgr->urls);
 	while (url != NULL) {
-		if (strcmp(httpd->url, url->url) == 0)
+		if (strcmp(httpd->url, url->url) == 0) {
 			break;
+		}
 		url = ISC_LIST_NEXT(url, link);
 	}
 	UNLOCK(&httpd->mgr->lock);
@@ -1001,7 +1017,7 @@ isc_httpd_recvdone(isc_task_t *task, isc_event_t *ev)
 			is_compressed = true;
 		}
 	}
-#endif
+#endif /* ifdef HAVE_ZLIB */
 
 	isc_httpd_response(httpd);
 	if ((httpd->flags & HTTPD_KEEPALIVE) != 0) {
@@ -1062,10 +1078,9 @@ out:
 }
 
 void
-isc_httpdmgr_shutdown(isc_httpdmgr_t **httpdmgrp)
-{
+isc_httpdmgr_shutdown(isc_httpdmgr_t **httpdmgrp) {
 	isc_httpdmgr_t *httpdmgr;
-	isc_httpd_t *	httpd;
+	isc_httpd_t *httpd;
 
 	REQUIRE(httpdmgrp != NULL);
 	httpdmgr = *httpdmgrp;
@@ -1091,16 +1106,16 @@ isc_httpdmgr_shutdown(isc_httpdmgr_t **httpdmgrp)
 }
 
 static isc_result_t
-grow_headerspace(isc_httpd_t *httpd)
-{
-	char *	     newspace;
+grow_headerspace(isc_httpd_t *httpd) {
+	char *newspace;
 	unsigned int newlen;
 	isc_region_t r;
 
 	isc_buffer_region(&httpd->headerbuffer, &r);
 	newlen = r.length + HTTP_SENDGROW;
-	if (newlen > HTTP_SEND_MAXLEN)
+	if (newlen > HTTP_SEND_MAXLEN) {
 		return (ISC_R_NOSPACE);
+	}
 
 	newspace = isc_mem_get(httpd->mgr->mctx, newlen);
 
@@ -1112,8 +1127,7 @@ grow_headerspace(isc_httpd_t *httpd)
 }
 
 isc_result_t
-isc_httpd_response(isc_httpd_t *httpd)
-{
+isc_httpd_response(isc_httpd_t *httpd) {
 	isc_result_t result;
 	unsigned int needlen;
 
@@ -1125,8 +1139,9 @@ isc_httpd_response(isc_httpd_t *httpd)
 
 	while (isc_buffer_availablelength(&httpd->headerbuffer) < needlen) {
 		result = grow_headerspace(httpd);
-		if (result != ISC_R_SUCCESS)
+		if (result != ISC_R_SUCCESS) {
 			return (result);
+		}
 	}
 
 	return (isc_buffer_printf(&httpd->headerbuffer, "%s %03u %s\r\n",
@@ -1135,8 +1150,7 @@ isc_httpd_response(isc_httpd_t *httpd)
 }
 
 isc_result_t
-isc_httpd_addheader(isc_httpd_t *httpd, const char *name, const char *val)
-{
+isc_httpd_addheader(isc_httpd_t *httpd, const char *name, const char *val) {
 	isc_result_t result;
 	unsigned int needlen;
 
@@ -1150,8 +1164,9 @@ isc_httpd_addheader(isc_httpd_t *httpd, const char *name, const char *val)
 
 	while (isc_buffer_availablelength(&httpd->headerbuffer) < needlen) {
 		result = grow_headerspace(httpd);
-		if (result != ISC_R_SUCCESS)
+		if (result != ISC_R_SUCCESS) {
 			return (result);
+		}
 	}
 
 	if (val != NULL) {
@@ -1164,27 +1179,26 @@ isc_httpd_addheader(isc_httpd_t *httpd, const char *name, const char *val)
 }
 
 isc_result_t
-isc_httpd_endheaders(isc_httpd_t *httpd)
-{
+isc_httpd_endheaders(isc_httpd_t *httpd) {
 	isc_result_t result;
 
 	REQUIRE(VALID_HTTPD(httpd));
 
 	while (isc_buffer_availablelength(&httpd->headerbuffer) < 2) {
 		result = grow_headerspace(httpd);
-		if (result != ISC_R_SUCCESS)
+		if (result != ISC_R_SUCCESS) {
 			return (result);
+		}
 	}
 
 	return (isc_buffer_printf(&httpd->headerbuffer, "\r\n"));
 }
 
 isc_result_t
-isc_httpd_addheaderuint(isc_httpd_t *httpd, const char *name, int val)
-{
+isc_httpd_addheaderuint(isc_httpd_t *httpd, const char *name, int val) {
 	isc_result_t result;
 	unsigned int needlen;
-	char	     buf[sizeof "18446744073709551616"];
+	char buf[sizeof "18446744073709551616"];
 
 	REQUIRE(VALID_HTTPD(httpd));
 
@@ -1196,8 +1210,9 @@ isc_httpd_addheaderuint(isc_httpd_t *httpd, const char *name, int val)
 
 	while (isc_buffer_availablelength(&httpd->headerbuffer) < needlen) {
 		result = grow_headerspace(httpd);
-		if (result != ISC_R_SUCCESS)
+		if (result != ISC_R_SUCCESS) {
 			return (result);
+		}
 	}
 
 	return (isc_buffer_printf(&httpd->headerbuffer, "%s: %s\r\n", name,
@@ -1205,10 +1220,9 @@ isc_httpd_addheaderuint(isc_httpd_t *httpd, const char *name, int val)
 }
 
 static void
-isc_httpd_senddone(isc_task_t *task, isc_event_t *ev)
-{
-	isc_httpd_t *	   httpd = ev->ev_arg;
-	isc_region_t	   r;
+isc_httpd_senddone(isc_task_t *task, isc_event_t *ev) {
+	isc_httpd_t *httpd = ev->ev_arg;
+	isc_region_t r;
 	isc_socketevent_t *sev = (isc_socketevent_t *)ev;
 
 	REQUIRE(VALID_HTTPD(httpd));
@@ -1255,8 +1269,7 @@ out:
 }
 
 static void
-reset_client(isc_httpd_t *httpd)
-{
+reset_client(isc_httpd_t *httpd) {
 	/*
 	 * Catch errors here.  We MUST be in RECV mode, and we MUST NOT have
 	 * any outstanding buffers.  If we have buffers, we have a leak.
@@ -1281,8 +1294,7 @@ reset_client(isc_httpd_t *httpd)
 
 isc_result_t
 isc_httpdmgr_addurl(isc_httpdmgr_t *httpdmgr, const char *url,
-		    isc_httpdaction_t *func, void *arg)
-{
+		    isc_httpdaction_t *func, void *arg) {
 	/* REQUIRE(VALID_HTTPDMGR(httpdmgr)); Dummy function */
 
 	return (isc_httpdmgr_addurl2(httpdmgr, url, false, func, arg));
@@ -1290,8 +1302,7 @@ isc_httpdmgr_addurl(isc_httpdmgr_t *httpdmgr, const char *url,
 
 isc_result_t
 isc_httpdmgr_addurl2(isc_httpdmgr_t *httpdmgr, const char *url, bool isstatic,
-		     isc_httpdaction_t *func, void *arg)
-{
+		     isc_httpdaction_t *func, void *arg) {
 	isc_httpdurl_t *item;
 
 	REQUIRE(VALID_HTTPDMGR(httpdmgr));
@@ -1320,8 +1331,7 @@ isc_httpdmgr_addurl2(isc_httpdmgr_t *httpdmgr, const char *url, bool isstatic,
 }
 
 void
-isc_httpd_setfinishhook(void (*fn)(void))
-{
+isc_httpd_setfinishhook(void (*fn)(void)) {
 #if ENABLE_AFL
 	finishhook = fn;
 #else  /* ENABLE_AFL */
