@@ -9,20 +9,18 @@
  * information regarding copyright ownership.
  */
 
-
 /*! \file */
 
-#include <config.h>
-
 #include <ctype.h>
 #include <errno.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
 #include <isc/file.h>
 #include <isc/lex.h>
 #include <isc/mem.h>
-#include <isc/msgs.h>
 #include <isc/parseint.h>
 #include <isc/print.h>
 #include <isc/stdio.h>
@@ -30,37 +28,37 @@
 #include <isc/util.h>
 
 typedef struct inputsource {
-	isc_result_t			result;
-	isc_boolean_t			is_file;
-	isc_boolean_t			need_close;
-	isc_boolean_t			at_eof;
-	isc_boolean_t			last_was_eol;
-	isc_buffer_t *			pushback;
-	unsigned int			ignored;
-	void *				input;
-	char *				name;
-	unsigned long			line;
-	unsigned long			saved_line;
-	ISC_LINK(struct inputsource)	link;
+	isc_result_t result;
+	bool is_file;
+	bool need_close;
+	bool at_eof;
+	bool last_was_eol;
+	isc_buffer_t *pushback;
+	unsigned int ignored;
+	void *input;
+	char *name;
+	unsigned long line;
+	unsigned long saved_line;
+	ISC_LINK(struct inputsource) link;
 } inputsource;
 
-#define LEX_MAGIC			ISC_MAGIC('L', 'e', 'x', '!')
-#define VALID_LEX(l)			ISC_MAGIC_VALID(l, LEX_MAGIC)
+#define LEX_MAGIC    ISC_MAGIC('L', 'e', 'x', '!')
+#define VALID_LEX(l) ISC_MAGIC_VALID(l, LEX_MAGIC)
 
 struct isc_lex {
 	/* Unlocked. */
-	unsigned int			magic;
-	isc_mem_t *			mctx;
-	size_t				max_token;
-	char *				data;
-	unsigned int			comments;
-	isc_boolean_t			comment_ok;
-	isc_boolean_t			last_was_eol;
-	unsigned int			brace_count;
-	unsigned int			paren_count;
-	unsigned int			saved_paren_count;
-	isc_lexspecials_t		specials;
-	LIST(struct inputsource)	sources;
+	unsigned int magic;
+	isc_mem_t *mctx;
+	size_t max_token;
+	char *data;
+	unsigned int comments;
+	bool comment_ok;
+	bool last_was_eol;
+	unsigned int brace_count;
+	unsigned int paren_count;
+	unsigned int saved_paren_count;
+	isc_lexspecials_t specials;
+	LIST(struct inputsource) sources;
 };
 
 static inline isc_result_t
@@ -68,12 +66,11 @@ grow_data(isc_lex_t *lex, size_t *remainingp, char **currp, char **prevp) {
 	char *tmp;
 
 	tmp = isc_mem_get(lex->mctx, lex->max_token * 2 + 1);
-	if (tmp == NULL)
-		return (ISC_R_NOMEMORY);
 	memmove(tmp, lex->data, lex->max_token + 1);
 	*currp = tmp + (*currp - lex->data);
-	if (*prevp != NULL)
+	if (*prevp != NULL) {
 		*prevp = tmp + (*prevp - lex->data);
+	}
 	isc_mem_put(lex->mctx, lex->data, lex->max_token + 1);
 	lex->data = tmp;
 	*remainingp += lex->max_token;
@@ -90,22 +87,17 @@ isc_lex_create(isc_mem_t *mctx, size_t max_token, isc_lex_t **lexp) {
 	 */
 	REQUIRE(lexp != NULL && *lexp == NULL);
 
-	if (max_token == 0U)
+	if (max_token == 0U) {
 		max_token = 1;
+	}
 
 	lex = isc_mem_get(mctx, sizeof(*lex));
-	if (lex == NULL)
-		return (ISC_R_NOMEMORY);
 	lex->data = isc_mem_get(mctx, max_token + 1);
-	if (lex->data == NULL) {
-		isc_mem_put(mctx, lex, sizeof(*lex));
-		return (ISC_R_NOMEMORY);
-	}
 	lex->mctx = mctx;
 	lex->max_token = max_token;
 	lex->comments = 0;
-	lex->comment_ok = ISC_TRUE;
-	lex->last_was_eol = ISC_TRUE;
+	lex->comment_ok = true;
+	lex->last_was_eol = true;
 	lex->brace_count = 0;
 	lex->paren_count = 0;
 	lex->saved_paren_count = 0;
@@ -128,16 +120,17 @@ isc_lex_destroy(isc_lex_t **lexp) {
 
 	REQUIRE(lexp != NULL);
 	lex = *lexp;
+	*lexp = NULL;
 	REQUIRE(VALID_LEX(lex));
 
-	while (!EMPTY(lex->sources))
+	while (!EMPTY(lex->sources)) {
 		RUNTIME_CHECK(isc_lex_close(lex) == ISC_R_SUCCESS);
-	if (lex->data != NULL)
+	}
+	if (lex->data != NULL) {
 		isc_mem_put(lex->mctx, lex->data, lex->max_token + 1);
+	}
 	lex->magic = 0;
 	isc_mem_put(lex->mctx, lex, sizeof(*lex));
-
-	*lexp = NULL;
 }
 
 unsigned int
@@ -186,34 +179,21 @@ isc_lex_setspecials(isc_lex_t *lex, isc_lexspecials_t specials) {
 }
 
 static inline isc_result_t
-new_source(isc_lex_t *lex, isc_boolean_t is_file, isc_boolean_t need_close,
-	   void *input, const char *name)
-{
+new_source(isc_lex_t *lex, bool is_file, bool need_close, void *input,
+	   const char *name) {
 	inputsource *source;
-	isc_result_t result;
 
 	source = isc_mem_get(lex->mctx, sizeof(*source));
-	if (source == NULL)
-		return (ISC_R_NOMEMORY);
 	source->result = ISC_R_SUCCESS;
 	source->is_file = is_file;
 	source->need_close = need_close;
-	source->at_eof = ISC_FALSE;
+	source->at_eof = false;
 	source->last_was_eol = lex->last_was_eol;
 	source->input = input;
 	source->name = isc_mem_strdup(lex->mctx, name);
-	if (source->name == NULL) {
-		isc_mem_put(lex->mctx, source, sizeof(*source));
-		return (ISC_R_NOMEMORY);
-	}
 	source->pushback = NULL;
-	result = isc_buffer_allocate(lex->mctx, &source->pushback,
-				     (unsigned int)lex->max_token);
-	if (result != ISC_R_SUCCESS) {
-		isc_mem_free(lex->mctx, source->name);
-		isc_mem_put(lex->mctx, source, sizeof(*source));
-		return (result);
-	}
+	isc_buffer_allocate(lex->mctx, &source->pushback,
+			    (unsigned int)lex->max_token);
 	source->ignored = 0;
 	source->line = 1;
 	ISC_LIST_INITANDPREPEND(lex->sources, source, link);
@@ -233,12 +213,14 @@ isc_lex_openfile(isc_lex_t *lex, const char *filename) {
 	REQUIRE(VALID_LEX(lex));
 
 	result = isc_stdio_open(filename, "r", &stream);
-	if (result != ISC_R_SUCCESS)
+	if (result != ISC_R_SUCCESS) {
 		return (result);
+	}
 
-	result = new_source(lex, ISC_TRUE, ISC_TRUE, stream, filename);
-	if (result != ISC_R_SUCCESS)
+	result = new_source(lex, true, true, stream, filename);
+	if (result != ISC_R_SUCCESS) {
 		(void)fclose(stream);
+	}
 	return (result);
 }
 
@@ -254,7 +236,7 @@ isc_lex_openstream(isc_lex_t *lex, FILE *stream) {
 
 	snprintf(name, sizeof(name), "stream-%p", stream);
 
-	return (new_source(lex, ISC_TRUE, ISC_FALSE, stream, name));
+	return (new_source(lex, true, false, stream, name));
 }
 
 isc_result_t
@@ -269,7 +251,7 @@ isc_lex_openbuffer(isc_lex_t *lex, isc_buffer_t *buffer) {
 
 	snprintf(name, sizeof(name), "buffer-%p", buffer);
 
-	return (new_source(lex, ISC_FALSE, ISC_FALSE, buffer, name));
+	return (new_source(lex, false, false, buffer, name));
 }
 
 isc_result_t
@@ -283,14 +265,16 @@ isc_lex_close(isc_lex_t *lex) {
 	REQUIRE(VALID_LEX(lex));
 
 	source = HEAD(lex->sources);
-	if (source == NULL)
+	if (source == NULL) {
 		return (ISC_R_NOMORE);
+	}
 
 	ISC_LIST_UNLINK(lex->sources, source, link);
 	lex->last_was_eol = source->last_was_eol;
 	if (source->is_file) {
-		if (source->need_close)
+		if (source->need_close) {
 			(void)fclose((FILE *)(source->input));
+		}
 	}
 	isc_mem_free(lex->mctx, source->name);
 	isc_buffer_free(&source->pushback);
@@ -318,12 +302,13 @@ static void
 pushback(inputsource *source, int c) {
 	REQUIRE(source->pushback->current > 0);
 	if (c == EOF) {
-		source->at_eof = ISC_FALSE;
+		source->at_eof = false;
 		return;
 	}
 	source->pushback->current--;
-	if (c == '\n')
+	if (c == '\n') {
 		source->line--;
+	}
 }
 
 static isc_result_t
@@ -335,9 +320,7 @@ pushandgrow(isc_lex_t *lex, inputsource *source, int c) {
 		isc_result_t result;
 
 		oldlen = isc_buffer_length(source->pushback);
-		result = isc_buffer_allocate(lex->mctx, &tbuf, oldlen * 2);
-		if (result != ISC_R_SUCCESS)
-			return (result);
+		isc_buffer_allocate(lex->mctx, &tbuf, oldlen * 2);
 		isc_buffer_usedregion(source->pushback, &used);
 		result = isc_buffer_copyregion(tbuf, &used);
 		INSIST(result == ISC_R_SUCCESS);
@@ -345,7 +328,7 @@ pushandgrow(isc_lex_t *lex, inputsource *source, int c) {
 		isc_buffer_free(&source->pushback);
 		source->pushback = tbuf;
 	}
-	isc_buffer_putuint8(source->pushback, (isc_uint8_t)c);
+	isc_buffer_putuint8(source->pushback, (uint8_t)c);
 	return (ISC_R_SUCCESS);
 }
 
@@ -353,16 +336,16 @@ isc_result_t
 isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 	inputsource *source;
 	int c;
-	isc_boolean_t done = ISC_FALSE;
-	isc_boolean_t no_comments = ISC_FALSE;
-	isc_boolean_t escaped = ISC_FALSE;
+	bool done = false;
+	bool no_comments = false;
+	bool escaped = false;
 	lexstate state = lexstate_start;
 	lexstate saved_state = lexstate_start;
 	isc_buffer_t *buffer;
 	FILE *stream;
 	char *curr, *prev;
 	size_t remaining;
-	isc_uint32_t as_ulong;
+	uint32_t as_ulong;
 	unsigned int saved_options;
 	isc_result_t result;
 
@@ -382,23 +365,21 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 		return (ISC_R_NOMORE);
 	}
 
-	if (source->result != ISC_R_SUCCESS)
+	if (source->result != ISC_R_SUCCESS) {
 		return (source->result);
+	}
 
 	lex->saved_paren_count = lex->paren_count;
 	source->saved_line = source->line;
 
-	if (isc_buffer_remaininglength(source->pushback) == 0 &&
-	    source->at_eof)
+	if (isc_buffer_remaininglength(source->pushback) == 0 && source->at_eof)
 	{
 		if ((options & ISC_LEXOPT_DNSMULTILINE) != 0 &&
-		    lex->paren_count != 0)
-		{
+		    lex->paren_count != 0) {
 			lex->paren_count = 0;
 			return (ISC_R_UNBALANCED);
 		}
-		if ((options & ISC_LEXOPT_BTEXT) != 0 &&
-		    lex->brace_count != 0)
+		if ((options & ISC_LEXOPT_BTEXT) != 0 && lex->brace_count != 0)
 		{
 			lex->brace_count = 0;
 			return (ISC_R_UNBALANCED);
@@ -413,8 +394,9 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 	isc_buffer_compact(source->pushback);
 
 	saved_options = options;
-	if ((options & ISC_LEXOPT_DNSMULTILINE) != 0 && lex->paren_count > 0)
+	if ((options & ISC_LEXOPT_DNSMULTILINE) != 0 && lex->paren_count > 0) {
 		options &= ~IWSEOL;
+	}
 
 	curr = lex->data;
 	*curr = '\0';
@@ -423,34 +405,35 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 	remaining = lex->max_token;
 
 #ifdef HAVE_FLOCKFILE
-	if (source->is_file)
+	if (source->is_file) {
 		flockfile(source->input);
-#endif
+	}
+#endif /* ifdef HAVE_FLOCKFILE */
 
 	do {
 		if (isc_buffer_remaininglength(source->pushback) == 0) {
 			if (source->is_file) {
 				stream = source->input;
 
-#if defined(HAVE_FLOCKFILE) && defined(HAVE_GETCUNLOCKED)
+#if defined(HAVE_FLOCKFILE) && defined(HAVE_GETC_UNLOCKED)
 				c = getc_unlocked(stream);
-#else
+#else  /* if defined(HAVE_FLOCKFILE) && defined(HAVE_GETC_UNLOCKED) */
 				c = getc(stream);
-#endif
+#endif /* if defined(HAVE_FLOCKFILE) && defined(HAVE_GETC_UNLOCKED) */
 				if (c == EOF) {
 					if (ferror(stream)) {
 						source->result = ISC_R_IOERROR;
 						result = source->result;
 						goto done;
 					}
-					source->at_eof = ISC_TRUE;
+					source->at_eof = true;
 				}
 			} else {
 				buffer = source->input;
 
 				if (buffer->current == buffer->used) {
 					c = EOF;
-					source->at_eof = ISC_TRUE;
+					source->at_eof = true;
 				} else {
 					c = *((unsigned char *)buffer->base +
 					      buffer->current);
@@ -467,40 +450,43 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 		}
 
 		if (!source->at_eof) {
-			if (state == lexstate_start)
+			if (state == lexstate_start) {
 				/* Token has not started yet. */
-				source->ignored =
-				   isc_buffer_consumedlength(source->pushback);
+				source->ignored = isc_buffer_consumedlength(
+					source->pushback);
+			}
 			c = isc_buffer_getuint8(source->pushback);
 		} else {
 			c = EOF;
 		}
 
-		if (c == '\n')
+		if (c == '\n') {
 			source->line++;
+		}
 
 		if (lex->comment_ok && !no_comments) {
 			if (!escaped && c == ';' &&
-			    ((lex->comments & ISC_LEXCOMMENT_DNSMASTERFILE)
-			     != 0)) {
+			    ((lex->comments & ISC_LEXCOMMENT_DNSMASTERFILE) !=
+			     0))
+			{
 				saved_state = state;
 				state = lexstate_eatline;
-				no_comments = ISC_TRUE;
+				no_comments = true;
 				continue;
 			} else if (c == '/' &&
 				   (lex->comments &
-				    (ISC_LEXCOMMENT_C|
-				     ISC_LEXCOMMENT_CPLUSPLUS)) != 0) {
+				    (ISC_LEXCOMMENT_C |
+				     ISC_LEXCOMMENT_CPLUSPLUS)) != 0)
+			{
 				saved_state = state;
 				state = lexstate_maybecomment;
-				no_comments = ISC_TRUE;
+				no_comments = true;
 				continue;
-			} else if (c == '#' &&
-				   ((lex->comments & ISC_LEXCOMMENT_SHELL)
-				    != 0)) {
+			} else if (c == '#' && ((lex->comments &
+						 ISC_LEXCOMMENT_SHELL) != 0)) {
 				saved_state = state;
 				state = lexstate_eatline;
-				no_comments = ISC_TRUE;
+				no_comments = true;
 				continue;
 			}
 		}
@@ -510,7 +496,7 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 		switch (state) {
 		case lexstate_start:
 			if (c == EOF) {
-				lex->last_was_eol = ISC_FALSE;
+				lex->last_was_eol = false;
 				if ((options & ISC_LEXOPT_DNSMULTILINE) != 0 &&
 				    lex->paren_count != 0) {
 					lex->paren_count = 0;
@@ -528,53 +514,53 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 					goto done;
 				}
 				tokenp->type = isc_tokentype_eof;
-				done = ISC_TRUE;
+				done = true;
 			} else if (c == ' ' || c == '\t') {
 				if (lex->last_was_eol &&
-				    (options & ISC_LEXOPT_INITIALWS)
-				    != 0) {
-					lex->last_was_eol = ISC_FALSE;
+				    (options & ISC_LEXOPT_INITIALWS) != 0) {
+					lex->last_was_eol = false;
 					tokenp->type = isc_tokentype_initialws;
 					tokenp->value.as_char = c;
-					done = ISC_TRUE;
+					done = true;
 				}
 			} else if (c == '\n') {
 				if ((options & ISC_LEXOPT_EOL) != 0) {
 					tokenp->type = isc_tokentype_eol;
-					done = ISC_TRUE;
+					done = true;
 				}
-				lex->last_was_eol = ISC_TRUE;
+				lex->last_was_eol = true;
 			} else if (c == '\r') {
-				if ((options & ISC_LEXOPT_EOL) != 0)
+				if ((options & ISC_LEXOPT_EOL) != 0) {
 					state = lexstate_crlf;
+				}
 			} else if (c == '"' &&
 				   (options & ISC_LEXOPT_QSTRING) != 0) {
-				lex->last_was_eol = ISC_FALSE;
-				no_comments = ISC_TRUE;
+				lex->last_was_eol = false;
+				no_comments = true;
 				state = lexstate_qstring;
 			} else if (lex->specials[c]) {
-				lex->last_was_eol = ISC_FALSE;
+				lex->last_was_eol = false;
 				if ((c == '(' || c == ')') &&
-				    (options & ISC_LEXOPT_DNSMULTILINE) != 0)
-				{
+				    (options & ISC_LEXOPT_DNSMULTILINE) != 0) {
 					if (c == '(') {
-						if (lex->paren_count == 0)
+						if (lex->paren_count == 0) {
 							options &= ~IWSEOL;
+						}
 						lex->paren_count++;
 					} else {
 						if (lex->paren_count == 0) {
 							result =
-							      ISC_R_UNBALANCED;
+								ISC_R_UNBALANCED;
 							goto done;
 						}
 						lex->paren_count--;
-						if (lex->paren_count == 0)
+						if (lex->paren_count == 0) {
 							options = saved_options;
+						}
 					}
 					continue;
 				} else if (c == '{' &&
-					   (options & ISC_LEXOPT_BTEXT) != 0)
-				{
+					   (options & ISC_LEXOPT_BTEXT) != 0) {
 					if (lex->brace_count != 0) {
 						result = ISC_R_UNBALANCED;
 						goto done;
@@ -582,51 +568,54 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 					lex->brace_count++;
 					options &= ~IWSEOL;
 					state = lexstate_btext;
-					no_comments = ISC_TRUE;
+					no_comments = true;
 					continue;
 				}
 				tokenp->type = isc_tokentype_special;
 				tokenp->value.as_char = c;
-				done = ISC_TRUE;
+				done = true;
 			} else if (isdigit((unsigned char)c) &&
 				   (options & ISC_LEXOPT_NUMBER) != 0) {
-				lex->last_was_eol = ISC_FALSE;
+				lex->last_was_eol = false;
 				if ((options & ISC_LEXOPT_OCTAL) != 0 &&
-				    (c == '8' || c == '9'))
+				    (c == '8' || c == '9')) {
 					state = lexstate_string;
-				else
+				} else {
 					state = lexstate_number;
+				}
 				goto no_read;
 			} else {
-				lex->last_was_eol = ISC_FALSE;
+				lex->last_was_eol = false;
 				state = lexstate_string;
 				goto no_read;
 			}
 			break;
 		case lexstate_crlf:
-			if (c != '\n')
+			if (c != '\n') {
 				pushback(source, c);
+			}
 			tokenp->type = isc_tokentype_eol;
-			done = ISC_TRUE;
-			lex->last_was_eol = ISC_TRUE;
+			done = true;
+			lex->last_was_eol = true;
 			break;
 		case lexstate_number:
 			if (c == EOF || !isdigit((unsigned char)c)) {
 				if (c == ' ' || c == '\t' || c == '\r' ||
-				    c == '\n' || c == EOF ||
-				    lex->specials[c]) {
+				    c == '\n' || c == EOF || lex->specials[c])
+				{
 					int base;
-					if ((options & ISC_LEXOPT_OCTAL) != 0)
+					if ((options & ISC_LEXOPT_OCTAL) != 0) {
 						base = 8;
-					else if ((options & ISC_LEXOPT_CNUMBER) != 0)
+					} else if ((options &
+						    ISC_LEXOPT_CNUMBER) != 0) {
 						base = 0;
-					else
+					} else {
 						base = 10;
+					}
 					pushback(source, c);
 
-					result = isc_parse_uint32(&as_ulong,
-								  lex->data,
-								  base);
+					result = isc_parse_uint32(
+						&as_ulong, lex->data, base);
 					if (result == ISC_R_SUCCESS) {
 						tokenp->type =
 							isc_tokentype_number;
@@ -641,17 +630,19 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 						v->as_textregion.base =
 							lex->data;
 						v->as_textregion.length =
-							(unsigned int)
-							(lex->max_token -
-							 remaining);
-					} else
+							(unsigned int)(lex->max_token -
+								       remaining);
+					} else {
 						goto done;
-					done = ISC_TRUE;
+					}
+					done = true;
 					continue;
-				} else if (!(options & ISC_LEXOPT_CNUMBER) ||
+				} else if ((options & ISC_LEXOPT_CNUMBER) ==
+						   0 ||
 					   ((c != 'x' && c != 'X') ||
-					   (curr != &lex->data[1]) ||
-					   (lex->data[0] != '0'))) {
+					    (curr != &lex->data[1]) ||
+					    (lex->data[0] != '0')))
+				{
 					/* Above test supports hex numbers */
 					state = lexstate_string;
 				}
@@ -660,10 +651,11 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 				state = lexstate_string;
 			}
 			if (remaining == 0U) {
-				result = grow_data(lex, &remaining,
-						   &curr, &prev);
-				if (result != ISC_R_SUCCESS)
+				result = grow_data(lex, &remaining, &curr,
+						   &prev);
+				if (result != ISC_R_SUCCESS) {
 					goto done;
+				}
 			}
 			INSIST(remaining > 0U);
 			*curr++ = c;
@@ -677,7 +669,8 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			 */
 			if (c == '\r' || c == '\n' || c == EOF ||
 			    (!escaped &&
-			     (c == ' ' || c == '\t' || lex->specials[c]))) {
+			     (c == ' ' || c == '\t' || lex->specials[c])))
+			{
 				pushback(source, c);
 				if (source->result != ISC_R_SUCCESS) {
 					result = source->result;
@@ -686,19 +679,21 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 				tokenp->type = isc_tokentype_string;
 				tokenp->value.as_textregion.base = lex->data;
 				tokenp->value.as_textregion.length =
-					(unsigned int)
-					(lex->max_token - remaining);
-				done = ISC_TRUE;
+					(unsigned int)(lex->max_token -
+						       remaining);
+				done = true;
 				continue;
 			}
-			if ((options & ISC_LEXOPT_ESCAPE) != 0)
-				escaped = (!escaped && c == '\\') ?
-						ISC_TRUE : ISC_FALSE;
+			if ((options & ISC_LEXOPT_ESCAPE) != 0) {
+				escaped = (!escaped && c == '\\') ? true
+								  : false;
+			}
 			if (remaining == 0U) {
-				result = grow_data(lex, &remaining,
-						   &curr, &prev);
-				if (result != ISC_R_SUCCESS)
+				result = grow_data(lex, &remaining, &curr,
+						   &prev);
+				if (result != ISC_R_SUCCESS) {
 					goto done;
+				}
 			}
 			INSIST(remaining > 0U);
 			*curr++ = c;
@@ -706,18 +701,19 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			remaining--;
 			break;
 		case lexstate_maybecomment:
-			if (c == '*' &&
-			    (lex->comments & ISC_LEXCOMMENT_C) != 0) {
+			if (c == '*' && (lex->comments & ISC_LEXCOMMENT_C) != 0)
+			{
 				state = lexstate_ccomment;
 				continue;
-			} else if (c == '/' &&
-			    (lex->comments & ISC_LEXCOMMENT_CPLUSPLUS) != 0) {
+			} else if (c == '/' && (lex->comments &
+						ISC_LEXCOMMENT_CPLUSPLUS) != 0)
+			{
 				state = lexstate_eatline;
 				continue;
 			}
 			pushback(source, c);
 			c = '/';
-			no_comments = ISC_FALSE;
+			no_comments = false;
 			state = saved_state;
 			goto no_read;
 		case lexstate_ccomment:
@@ -725,8 +721,9 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 				result = ISC_R_UNEXPECTEDEND;
 				goto done;
 			}
-			if (c == '*')
+			if (c == '*') {
 				state = lexstate_ccommentend;
+			}
 			break;
 		case lexstate_ccommentend:
 			if (c == EOF) {
@@ -741,15 +738,16 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 				 * numbers.
 				 */
 				c = ' ';
-				no_comments = ISC_FALSE;
+				no_comments = false;
 				state = saved_state;
 				goto no_read;
-			} else if (c != '*')
+			} else if (c != '*') {
 				state = lexstate_ccomment;
+			}
 			break;
 		case lexstate_eatline:
 			if ((c == '\n') || (c == EOF)) {
-				no_comments = ISC_FALSE;
+				no_comments = false;
 				state = saved_state;
 				goto no_read;
 			}
@@ -761,7 +759,7 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			}
 			if (c == '"') {
 				if (escaped) {
-					escaped = ISC_FALSE;
+					escaped = false;
 					/*
 					 * Overwrite the preceding backslash.
 					 */
@@ -772,27 +770,30 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 					tokenp->value.as_textregion.base =
 						lex->data;
 					tokenp->value.as_textregion.length =
-						(unsigned int)
-						(lex->max_token - remaining);
-					no_comments = ISC_FALSE;
-					done = ISC_TRUE;
+						(unsigned int)(lex->max_token -
+							       remaining);
+					no_comments = false;
+					done = true;
 				}
 			} else {
 				if (c == '\n' && !escaped &&
-			    (options & ISC_LEXOPT_QSTRINGMULTILINE) == 0) {
+				    (options & ISC_LEXOPT_QSTRINGMULTILINE) ==
+					    0) {
 					pushback(source, c);
 					result = ISC_R_UNBALANCEDQUOTES;
 					goto done;
 				}
-				if (c == '\\' && !escaped)
-					escaped = ISC_TRUE;
-				else
-					escaped = ISC_FALSE;
+				if (c == '\\' && !escaped) {
+					escaped = true;
+				} else {
+					escaped = false;
+				}
 				if (remaining == 0U) {
 					result = grow_data(lex, &remaining,
 							   &curr, &prev);
-					if (result != ISC_R_SUCCESS)
+					if (result != ISC_R_SUCCESS) {
 						goto done;
+					}
 				}
 				INSIST(remaining > 0U);
 				prev = curr;
@@ -808,13 +809,13 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			}
 			if (c == '{') {
 				if (escaped) {
-					escaped = ISC_FALSE;
+					escaped = false;
 				} else {
 					lex->brace_count++;
 				}
 			} else if (c == '}') {
 				if (escaped) {
-					escaped = ISC_FALSE;
+					escaped = false;
 				} else {
 					INSIST(lex->brace_count > 0);
 					lex->brace_count--;
@@ -825,24 +826,26 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 					tokenp->value.as_textregion.base =
 						lex->data;
 					tokenp->value.as_textregion.length =
-						(unsigned int) (lex->max_token -
-								remaining);
-					no_comments = ISC_FALSE;
-					done = ISC_TRUE;
+						(unsigned int)(lex->max_token -
+							       remaining);
+					no_comments = false;
+					done = true;
 					break;
 				}
 			}
 
-			if (c == '\\' && !escaped)
-				escaped = ISC_TRUE;
-			else
-				escaped = ISC_FALSE;
+			if (c == '\\' && !escaped) {
+				escaped = true;
+			} else {
+				escaped = false;
+			}
 
 			if (remaining == 0U) {
-				result = grow_data(lex, &remaining,
-						   &curr, &prev);
-				if (result != ISC_R_SUCCESS)
+				result = grow_data(lex, &remaining, &curr,
+						   &prev);
+				if (result != ISC_R_SUCCESS) {
 					goto done;
+				}
 			}
 			INSIST(remaining > 0U);
 			prev = curr;
@@ -851,83 +854,90 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			remaining--;
 			break;
 		default:
-			FATAL_ERROR(__FILE__, __LINE__,
-				    isc_msgcat_get(isc_msgcat, ISC_MSGSET_LEX,
-						   ISC_MSG_UNEXPECTEDSTATE,
-						   "Unexpected state %d"),
+			FATAL_ERROR(__FILE__, __LINE__, "Unexpected state %d",
 				    state);
-			/* Does not return. */
 		}
-
 	} while (!done);
 
 	result = ISC_R_SUCCESS;
- done:
+done:
 #ifdef HAVE_FLOCKFILE
-	if (source->is_file)
+	if (source->is_file) {
 		funlockfile(source->input);
-#endif
+	}
+#endif /* ifdef HAVE_FLOCKFILE */
 	return (result);
 }
 
 isc_result_t
 isc_lex_getmastertoken(isc_lex_t *lex, isc_token_t *token,
-		       isc_tokentype_t expect, isc_boolean_t eol)
-{
+		       isc_tokentype_t expect, bool eol) {
 	unsigned int options = ISC_LEXOPT_EOL | ISC_LEXOPT_EOF |
 			       ISC_LEXOPT_DNSMULTILINE | ISC_LEXOPT_ESCAPE;
 	isc_result_t result;
 
-	if (expect == isc_tokentype_qstring)
+	if (expect == isc_tokentype_qstring) {
 		options |= ISC_LEXOPT_QSTRING;
-	else if (expect == isc_tokentype_number)
+	} else if (expect == isc_tokentype_number) {
 		options |= ISC_LEXOPT_NUMBER;
+	}
 	result = isc_lex_gettoken(lex, options, token);
-	if (result == ISC_R_RANGE)
+	if (result == ISC_R_RANGE) {
 		isc_lex_ungettoken(lex, token);
-	if (result != ISC_R_SUCCESS)
+	}
+	if (result != ISC_R_SUCCESS) {
 		return (result);
+	}
 
 	if (eol && ((token->type == isc_tokentype_eol) ||
 		    (token->type == isc_tokentype_eof)))
+	{
 		return (ISC_R_SUCCESS);
+	}
 	if (token->type == isc_tokentype_string &&
-	    expect == isc_tokentype_qstring)
+	    expect == isc_tokentype_qstring) {
 		return (ISC_R_SUCCESS);
+	}
 	if (token->type != expect) {
 		isc_lex_ungettoken(lex, token);
 		if (token->type == isc_tokentype_eol ||
-		    token->type == isc_tokentype_eof)
+		    token->type == isc_tokentype_eof) {
 			return (ISC_R_UNEXPECTEDEND);
-		if (expect == isc_tokentype_number)
+		}
+		if (expect == isc_tokentype_number) {
 			return (ISC_R_BADNUMBER);
+		}
 		return (ISC_R_UNEXPECTEDTOKEN);
 	}
 	return (ISC_R_SUCCESS);
 }
 
 isc_result_t
-isc_lex_getoctaltoken(isc_lex_t *lex, isc_token_t *token, isc_boolean_t eol)
-{
+isc_lex_getoctaltoken(isc_lex_t *lex, isc_token_t *token, bool eol) {
 	unsigned int options = ISC_LEXOPT_EOL | ISC_LEXOPT_EOF |
-			       ISC_LEXOPT_DNSMULTILINE | ISC_LEXOPT_ESCAPE|
+			       ISC_LEXOPT_DNSMULTILINE | ISC_LEXOPT_ESCAPE |
 			       ISC_LEXOPT_NUMBER | ISC_LEXOPT_OCTAL;
 	isc_result_t result;
 
 	result = isc_lex_gettoken(lex, options, token);
-	if (result == ISC_R_RANGE)
+	if (result == ISC_R_RANGE) {
 		isc_lex_ungettoken(lex, token);
-	if (result != ISC_R_SUCCESS)
+	}
+	if (result != ISC_R_SUCCESS) {
 		return (result);
+	}
 
 	if (eol && ((token->type == isc_tokentype_eol) ||
 		    (token->type == isc_tokentype_eof)))
+	{
 		return (ISC_R_SUCCESS);
+	}
 	if (token->type != isc_tokentype_number) {
 		isc_lex_ungettoken(lex, token);
 		if (token->type == isc_tokentype_eol ||
-		    token->type == isc_tokentype_eof)
+		    token->type == isc_tokentype_eof) {
 			return (ISC_R_UNEXPECTEDEND);
+		}
 		return (ISC_R_BADNUMBER);
 	}
 	return (ISC_R_SUCCESS);
@@ -952,12 +962,11 @@ isc_lex_ungettoken(isc_lex_t *lex, isc_token_t *tokenp) {
 	isc_buffer_first(source->pushback);
 	lex->paren_count = lex->saved_paren_count;
 	source->line = source->saved_line;
-	source->at_eof = ISC_FALSE;
+	source->at_eof = false;
 }
 
 void
-isc_lex_getlasttokentext(isc_lex_t *lex, isc_token_t *tokenp, isc_region_t *r)
-{
+isc_lex_getlasttokentext(isc_lex_t *lex, isc_token_t *tokenp, isc_region_t *r) {
 	inputsource *source;
 
 	REQUIRE(VALID_LEX(lex));
@@ -983,8 +992,9 @@ isc_lex_getsourcename(isc_lex_t *lex) {
 	REQUIRE(VALID_LEX(lex));
 	source = HEAD(lex->sources);
 
-	if (source == NULL)
+	if (source == NULL) {
 		return (NULL);
+	}
 
 	return (source->name);
 }
@@ -996,8 +1006,9 @@ isc_lex_getsourceline(isc_lex_t *lex) {
 	REQUIRE(VALID_LEX(lex));
 	source = HEAD(lex->sources);
 
-	if (source == NULL)
+	if (source == NULL) {
 		return (0);
+	}
 
 	return (source->line);
 }
@@ -1010,11 +1021,10 @@ isc_lex_setsourcename(isc_lex_t *lex, const char *name) {
 	REQUIRE(VALID_LEX(lex));
 	source = HEAD(lex->sources);
 
-	if (source == NULL)
+	if (source == NULL) {
 		return (ISC_R_NOTFOUND);
+	}
 	newname = isc_mem_strdup(lex->mctx, name);
-	if (newname == NULL)
-		return (ISC_R_NOMEMORY);
 	isc_mem_free(lex->mctx, source->name);
 	source->name = newname;
 	return (ISC_R_SUCCESS);
@@ -1027,14 +1037,15 @@ isc_lex_setsourceline(isc_lex_t *lex, unsigned long line) {
 	REQUIRE(VALID_LEX(lex));
 	source = HEAD(lex->sources);
 
-	if (source == NULL)
+	if (source == NULL) {
 		return (ISC_R_NOTFOUND);
+	}
 
 	source->line = line;
 	return (ISC_R_SUCCESS);
 }
 
-isc_boolean_t
+bool
 isc_lex_isfile(isc_lex_t *lex) {
 	inputsource *source;
 
@@ -1042,8 +1053,9 @@ isc_lex_isfile(isc_lex_t *lex) {
 
 	source = HEAD(lex->sources);
 
-	if (source == NULL)
-		return (ISC_FALSE);
+	if (source == NULL) {
+		return (false);
+	}
 
 	return (source->is_file);
 }
