@@ -10,17 +10,17 @@
  */
 
 #include <stdbool.h>
-
 #include <sys/types.h>
 
 #if defined(HAVE_SYS_SYSCTL_H) && !defined(__linux__)
 #if defined(HAVE_SYS_PARAM_H)
 #include <sys/param.h>
-#endif
+#endif /* if defined(HAVE_SYS_PARAM_H) */
 #include <sys/sysctl.h>
-#endif
+#endif /* if defined(HAVE_SYS_SYSCTL_H) && !defined(__linux__) */
 #include <errno.h>
 #include <fcntl.h>
+#include <sys/uio.h>
 #include <unistd.h>
 
 #include <isc/log.h>
@@ -31,11 +31,9 @@
 #include <isc/string.h>
 #include <isc/util.h>
 
-#include <sys/uio.h>
-
 #ifndef socklen_t
 #define socklen_t unsigned int
-#endif
+#endif /* ifndef socklen_t */
 
 /*%
  * Definitions about UDP port range specification.  This is a total mess of
@@ -61,19 +59,20 @@
  */
 #if defined(__FreeBSD__) || defined(__APPLE__) || defined(__DragonFly__)
 #define USE_SYSCTL_PORTRANGE
-#define SYSCTL_V4PORTRANGE_LOW "net.inet.ip.portrange.hifirst"
+#define SYSCTL_V4PORTRANGE_LOW	"net.inet.ip.portrange.hifirst"
 #define SYSCTL_V4PORTRANGE_HIGH "net.inet.ip.portrange.hilast"
-#define SYSCTL_V6PORTRANGE_LOW "net.inet.ip.portrange.hifirst"
+#define SYSCTL_V6PORTRANGE_LOW	"net.inet.ip.portrange.hifirst"
 #define SYSCTL_V6PORTRANGE_HIGH "net.inet.ip.portrange.hilast"
-#endif
+#endif /* if defined(__FreeBSD__) || defined(__APPLE__) || \
+	* defined(__DragonFly__) */
 
 #ifdef __NetBSD__
 #define USE_SYSCTL_PORTRANGE
-#define SYSCTL_V4PORTRANGE_LOW "net.inet.ip.anonportmin"
+#define SYSCTL_V4PORTRANGE_LOW	"net.inet.ip.anonportmin"
 #define SYSCTL_V4PORTRANGE_HIGH "net.inet.ip.anonportmax"
-#define SYSCTL_V6PORTRANGE_LOW "net.inet6.ip6.anonportmin"
+#define SYSCTL_V6PORTRANGE_LOW	"net.inet6.ip6.anonportmin"
 #define SYSCTL_V6PORTRANGE_HIGH "net.inet6.ip6.anonportmax"
-#endif
+#endif /* ifdef __NetBSD__ */
 
 #else /* !HAVE_SYSCTLBYNAME */
 
@@ -88,16 +87,16 @@
 		CTL_NET, PF_INET, IPPROTO_IP, IPCTL_IPPORT_HILASTAUTO \
 	}
 /* Same for IPv6 */
-#define SYSCTL_V6PORTRANGE_LOW SYSCTL_V4PORTRANGE_LOW
+#define SYSCTL_V6PORTRANGE_LOW	SYSCTL_V4PORTRANGE_LOW
 #define SYSCTL_V6PORTRANGE_HIGH SYSCTL_V4PORTRANGE_HIGH
-#endif
+#endif /* ifdef __OpenBSD__ */
 
 #endif /* HAVE_SYSCTLBYNAME */
 
 static isc_once_t once_ipv6only = ISC_ONCE_INIT;
 #ifdef __notyet__
 static isc_once_t once_ipv6pktinfo = ISC_ONCE_INIT;
-#endif
+#endif /* ifdef __notyet__ */
 
 #ifndef ISC_CMSG_IP_TOS
 #ifdef __APPLE__
@@ -118,27 +117,26 @@ static isc_result_t ipv6pktinfo_result = ISC_R_NOTFOUND;
 static unsigned int dscp_result = 0;
 
 static isc_result_t
-try_proto(int domain)
-{
-	int	     s;
+try_proto(int domain) {
+	int s;
 	isc_result_t result = ISC_R_SUCCESS;
-	char	     strbuf[ISC_STRERRORSIZE];
+	char strbuf[ISC_STRERRORSIZE];
 
 	s = socket(domain, SOCK_STREAM, 0);
 	if (s == -1) {
 		switch (errno) {
 #ifdef EAFNOSUPPORT
 		case EAFNOSUPPORT:
-#endif
+#endif /* ifdef EAFNOSUPPORT */
 #ifdef EPFNOSUPPORT
 		case EPFNOSUPPORT:
-#endif
+#endif /* ifdef EPFNOSUPPORT */
 #ifdef EPROTONOSUPPORT
 		case EPROTONOSUPPORT:
-#endif
+#endif /* ifdef EPROTONOSUPPORT */
 #ifdef EINVAL
 		case EINVAL:
-#endif
+#endif /* ifdef EINVAL */
 			return (ISC_R_NOTFOUND);
 		default:
 			strerror_r(errno, strbuf, sizeof(strbuf));
@@ -150,14 +148,14 @@ try_proto(int domain)
 
 	if (domain == PF_INET6) {
 		struct sockaddr_in6 sin6;
-		unsigned int	    len;
+		unsigned int len;
 
 		/*
 		 * Check to see if IPv6 is broken, as is common on Linux.
 		 */
 		len = sizeof(sin6);
-		if (getsockname(s, (struct sockaddr *)&sin6, (void *)&len) <
-		    0) {
+		if (getsockname(s, (struct sockaddr *)&sin6, (void *)&len) < 0)
+		{
 			isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 				      ISC_LOGMODULE_SOCKET, ISC_LOG_ERROR,
 				      "retrieving the address of an IPv6 "
@@ -167,9 +165,9 @@ try_proto(int domain)
 				      "IPv6 is not supported.");
 			result = ISC_R_NOTFOUND;
 		} else {
-			if (len == sizeof(struct sockaddr_in6))
+			if (len == sizeof(struct sockaddr_in6)) {
 				result = ISC_R_SUCCESS;
-			else {
+			} else {
 				isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 					      ISC_LOGMODULE_SOCKET,
 					      ISC_LOG_ERROR,
@@ -190,49 +188,43 @@ try_proto(int domain)
 }
 
 static void
-initialize_action(void)
-{
+initialize_action(void) {
 	ipv4_result = try_proto(PF_INET);
 	ipv6_result = try_proto(PF_INET6);
 #ifdef ISC_PLATFORM_HAVESYSUNH
 	unix_result = try_proto(PF_UNIX);
-#endif
+#endif /* ifdef ISC_PLATFORM_HAVESYSUNH */
 }
 
 static void
-initialize(void)
-{
+initialize(void) {
 	RUNTIME_CHECK(isc_once_do(&once, initialize_action) == ISC_R_SUCCESS);
 }
 
 isc_result_t
-isc_net_probeipv4(void)
-{
+isc_net_probeipv4(void) {
 	initialize();
 	return (ipv4_result);
 }
 
 isc_result_t
-isc_net_probeipv6(void)
-{
+isc_net_probeipv6(void) {
 	initialize();
 	return (ipv6_result);
 }
 
 isc_result_t
-isc_net_probeunix(void)
-{
+isc_net_probeunix(void) {
 	initialize();
 	return (unix_result);
 }
 
 static void
-try_ipv6only(void)
-{
+try_ipv6only(void) {
 #ifdef IPV6_V6ONLY
-	int  s, on;
+	int s, on;
 	char strbuf[ISC_STRERRORSIZE];
-#endif
+#endif /* ifdef IPV6_V6ONLY */
 	isc_result_t result;
 
 	result = isc_net_probeipv6();
@@ -244,7 +236,7 @@ try_ipv6only(void)
 #ifndef IPV6_V6ONLY
 	ipv6only_result = ISC_R_NOTFOUND;
 	return;
-#else
+#else  /* ifndef IPV6_V6ONLY */
 	/* check for TCP sockets */
 	s = socket(PF_INET6, SOCK_STREAM, 0);
 	if (s == -1) {
@@ -288,20 +280,18 @@ close:
 }
 
 static void
-initialize_ipv6only(void)
-{
+initialize_ipv6only(void) {
 	RUNTIME_CHECK(isc_once_do(&once_ipv6only, try_ipv6only) ==
 		      ISC_R_SUCCESS);
 }
 
 #ifdef __notyet__
 static void
-try_ipv6pktinfo(void)
-{
-	int	     s, on;
-	char	     strbuf[ISC_STRERRORSIZE];
+try_ipv6pktinfo(void) {
+	int s, on;
+	char strbuf[ISC_STRERRORSIZE];
 	isc_result_t result;
-	int	     optname;
+	int optname;
 
 	result = isc_net_probeipv6();
 	if (result != ISC_R_SUCCESS) {
@@ -321,9 +311,9 @@ try_ipv6pktinfo(void)
 
 #ifdef IPV6_RECVPKTINFO
 	optname = IPV6_RECVPKTINFO;
-#else
+#else  /* ifdef IPV6_RECVPKTINFO */
 	optname = IPV6_PKTINFO;
-#endif
+#endif /* ifdef IPV6_RECVPKTINFO */
 	on = 1;
 	if (setsockopt(s, IPPROTO_IPV6, optname, &on, sizeof(on)) < 0) {
 		ipv6pktinfo_result = ISC_R_NOTFOUND;
@@ -338,23 +328,20 @@ close:
 }
 
 static void
-initialize_ipv6pktinfo(void)
-{
+initialize_ipv6pktinfo(void) {
 	RUNTIME_CHECK(isc_once_do(&once_ipv6pktinfo, try_ipv6pktinfo) ==
 		      ISC_R_SUCCESS);
 }
-#endif
+#endif /* ifdef __notyet__ */
 
 isc_result_t
-isc_net_probe_ipv6only(void)
-{
+isc_net_probe_ipv6only(void) {
 	initialize_ipv6only();
 	return (ipv6only_result);
 }
 
 isc_result_t
-isc_net_probe_ipv6pktinfo(void)
-{
+isc_net_probe_ipv6pktinfo(void) {
 /*
  * XXXWPK if pktinfo were supported then we could listen on :: for ipv6 and get
  * the information about the destination address from pktinfo structure passed
@@ -366,18 +353,17 @@ isc_net_probe_ipv6pktinfo(void)
  */
 #ifdef __notyet__
 	initialize_ipv6pktinfo();
-#endif
+#endif /* ifdef __notyet__ */
 	return (ipv6pktinfo_result);
 }
 
 #if ISC_CMSG_IP_TOS || defined(IPV6_TCLASS)
 
 static inline socklen_t
-cmsg_len(socklen_t len)
-{
+cmsg_len(socklen_t len) {
 #ifdef CMSG_LEN
 	return (CMSG_LEN(len));
-#else
+#else  /* ifdef CMSG_LEN */
 	socklen_t hdrlen;
 
 	/*
@@ -386,16 +372,15 @@ cmsg_len(socklen_t len)
 	 */
 	hdrlen = (socklen_t)CMSG_DATA(((struct cmsghdr *)NULL));
 	return (hdrlen + len);
-#endif
+#endif /* ifdef CMSG_LEN */
 }
 
 static inline socklen_t
-cmsg_space(socklen_t len)
-{
+cmsg_space(socklen_t len) {
 #ifdef CMSG_SPACE
 	return (CMSG_SPACE(len));
-#else
-	struct msghdr	msg;
+#else  /* ifdef CMSG_SPACE */
+	struct msghdr msg;
 	struct cmsghdr *cmsgp;
 	/*
 	 * XXX: The buffer length is an ad-hoc value, but should be enough
@@ -411,40 +396,40 @@ cmsg_space(socklen_t len)
 	cmsgp->cmsg_len = cmsg_len(len);
 
 	cmsgp = CMSG_NXTHDR(&msg, cmsgp);
-	if (cmsgp != NULL)
+	if (cmsgp != NULL) {
 		return ((char *)cmsgp - (char *)msg.msg_control);
-	else
+	} else {
 		return (0);
-#endif
+	}
+#endif /* ifdef CMSG_SPACE */
 }
 
 /*
  * Make a fd non-blocking.
  */
 static isc_result_t
-make_nonblock(int fd)
-{
-	int  ret;
-	int  flags;
+make_nonblock(int fd) {
+	int ret;
+	int flags;
 	char strbuf[ISC_STRERRORSIZE];
 #ifdef USE_FIONBIO_IOCTL
 	int on = 1;
 
 	ret = ioctl(fd, FIONBIO, (char *)&on);
-#else
+#else  /* ifdef USE_FIONBIO_IOCTL */
 	flags = fcntl(fd, F_GETFL, 0);
 	flags |= PORT_NONBLOCK;
 	ret = fcntl(fd, F_SETFL, flags);
-#endif
+#endif /* ifdef USE_FIONBIO_IOCTL */
 
 	if (ret == -1) {
 		strerror_r(errno, strbuf, sizeof(strbuf));
 		UNEXPECTED_ERROR(__FILE__, __LINE__,
 #ifdef USE_FIONBIO_IOCTL
 				 "ioctl(%d, FIONBIO, &on): %s", fd,
-#else
+#else  /* ifdef USE_FIONBIO_IOCTL */
 				 "fcntl(%d, F_SETFL, %d): %s", fd, flags,
-#endif
+#endif /* ifdef USE_FIONBIO_IOCTL */
 				 strbuf);
 
 		return (ISC_R_UNEXPECTED);
@@ -454,21 +439,20 @@ make_nonblock(int fd)
 }
 
 static bool
-cmsgsend(int s, int level, int type, struct addrinfo *res)
-{
-	char			strbuf[ISC_STRERRORSIZE];
+cmsgsend(int s, int level, int type, struct addrinfo *res) {
+	char strbuf[ISC_STRERRORSIZE];
 	struct sockaddr_storage ss;
-	socklen_t		len = sizeof(ss);
-	struct msghdr		msg;
+	socklen_t len = sizeof(ss);
+	struct msghdr msg;
 	union {
 		struct cmsghdr h;
-		unsigned char  b[256];
+		unsigned char b[256];
 	} control;
 	struct cmsghdr *cmsgp;
-	int		dscp = (46 << 2); /* Expedited forwarding. */
-	struct iovec	iovec;
-	char		buf[1] = { 0 };
-	isc_result_t	result;
+	int dscp = (46 << 2); /* Expedited forwarding. */
+	struct iovec iovec;
+	char buf[1] = { 0 };
+	isc_result_t result;
 
 	if (bind(s, res->ai_addr, res->ai_addrlen) < 0) {
 		strerror_r(errno, strbuf, sizeof(strbuf));
@@ -510,7 +494,7 @@ cmsgsend(int s, int level, int type, struct addrinfo *res)
 		*(unsigned char *)CMSG_DATA(cmsgp) = dscp;
 		msg.msg_controllen += cmsg_space(sizeof(char));
 		break;
-#endif
+#endif /* ifdef IP_TOS */
 #ifdef IPV6_TCLASS
 	case IPV6_TCLASS:
 		memset(cmsgp, 0, cmsg_space(sizeof(dscp)));
@@ -520,22 +504,22 @@ cmsgsend(int s, int level, int type, struct addrinfo *res)
 		memmove(CMSG_DATA(cmsgp), &dscp, sizeof(dscp));
 		msg.msg_controllen += cmsg_space(sizeof(dscp));
 		break;
-#endif
+#endif /* ifdef IPV6_TCLASS */
 	default:
 		INSIST(0);
 		ISC_UNREACHABLE();
 	}
 
 	if (sendmsg(s, &msg, 0) < 0) {
-		int	    debug = ISC_LOG_DEBUG(10);
+		int debug = ISC_LOG_DEBUG(10);
 		const char *typestr;
 		switch (errno) {
 #ifdef ENOPROTOOPT
 		case ENOPROTOOPT:
-#endif
+#endif /* ifdef ENOPROTOOPT */
 #ifdef EOPNOTSUPP
 		case EOPNOTSUPP:
-#endif
+#endif /* ifdef EOPNOTSUPP */
 		case EINVAL:
 		case EPERM:
 			break;
@@ -575,20 +559,20 @@ cmsgsend(int s, int level, int type, struct addrinfo *res)
 	msg.msg_controllen = 0;
 	msg.msg_flags = 0;
 
-	if (recvmsg(s, &msg, 0) < 0)
+	if (recvmsg(s, &msg, 0) < 0) {
 		return (false);
+	}
 
 	return (true);
 }
-#endif
+#endif /* if ISC_CMSG_IP_TOS || defined(IPV6_TCLASS) */
 
 static void
-try_dscp_v4(void)
-{
+try_dscp_v4(void) {
 #ifdef IP_TOS
-	char		strbuf[ISC_STRERRORSIZE];
+	char strbuf[ISC_STRERRORSIZE];
 	struct addrinfo hints, *res0;
-	int		s, dscp = 0, n;
+	int s, dscp = 0, n;
 #ifdef IP_RECVTOS
 	int on = 1;
 #endif /* IP_RECVTOS */
@@ -599,9 +583,9 @@ try_dscp_v4(void)
 	hints.ai_protocol = IPPROTO_UDP;
 #ifdef AI_NUMERICHOST
 	hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
-#else
+#else  /* ifdef AI_NUMERICHOST */
 	hints.ai_flags = AI_PASSIVE;
-#endif
+#endif /* ifdef AI_NUMERICHOST */
 
 	n = getaddrinfo("127.0.0.1", NULL, &hints, &res0);
 	if (n != 0 || res0 == NULL) {
@@ -622,18 +606,21 @@ try_dscp_v4(void)
 		return;
 	}
 
-	if (setsockopt(s, IPPROTO_IP, IP_TOS, &dscp, sizeof(dscp)) == 0)
+	if (setsockopt(s, IPPROTO_IP, IP_TOS, &dscp, sizeof(dscp)) == 0) {
 		dscp_result |= ISC_NET_DSCPSETV4;
+	}
 
 #ifdef IP_RECVTOS
 	on = 1;
-	if (setsockopt(s, IPPROTO_IP, IP_RECVTOS, &on, sizeof(on)) == 0)
+	if (setsockopt(s, IPPROTO_IP, IP_RECVTOS, &on, sizeof(on)) == 0) {
 		dscp_result |= ISC_NET_DSCPRECVV4;
+	}
 #endif /* IP_RECVTOS */
 
 #if ISC_CMSG_IP_TOS
-	if (cmsgsend(s, IPPROTO_IP, IP_TOS, res0))
+	if (cmsgsend(s, IPPROTO_IP, IP_TOS, res0)) {
 		dscp_result |= ISC_NET_DSCPPKTV4;
+	}
 #endif /* ISC_CMSG_IP_TOS */
 
 	freeaddrinfo(res0);
@@ -643,12 +630,11 @@ try_dscp_v4(void)
 }
 
 static void
-try_dscp_v6(void)
-{
+try_dscp_v6(void) {
 #ifdef IPV6_TCLASS
-	char		strbuf[ISC_STRERRORSIZE];
+	char strbuf[ISC_STRERRORSIZE];
 	struct addrinfo hints, *res0;
-	int		s, dscp = 0, n;
+	int s, dscp = 0, n;
 #if defined(IPV6_RECVTCLASS)
 	int on = 1;
 #endif /* IPV6_RECVTCLASS */
@@ -659,9 +645,9 @@ try_dscp_v6(void)
 	hints.ai_protocol = IPPROTO_UDP;
 #ifdef AI_NUMERICHOST
 	hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
-#else
+#else  /* ifdef AI_NUMERICHOST */
 	hints.ai_flags = AI_PASSIVE;
-#endif
+#endif /* ifdef AI_NUMERICHOST */
 
 	n = getaddrinfo("::1", NULL, &hints, &res0);
 	if (n != 0 || res0 == NULL) {
@@ -681,16 +667,21 @@ try_dscp_v6(void)
 		return;
 	}
 	if (setsockopt(s, IPPROTO_IPV6, IPV6_TCLASS, &dscp, sizeof(dscp)) == 0)
+	{
 		dscp_result |= ISC_NET_DSCPSETV6;
+	}
 
 #ifdef IPV6_RECVTCLASS
 	on = 1;
 	if (setsockopt(s, IPPROTO_IPV6, IPV6_RECVTCLASS, &on, sizeof(on)) == 0)
+	{
 		dscp_result |= ISC_NET_DSCPRECVV6;
+	}
 #endif /* IPV6_RECVTCLASS */
 
-	if (cmsgsend(s, IPPROTO_IPV6, IPV6_TCLASS, res0))
+	if (cmsgsend(s, IPPROTO_IPV6, IPV6_TCLASS, res0)) {
 		dscp_result |= ISC_NET_DSCPPKTV6;
+	}
 
 	freeaddrinfo(res0);
 	close(s);
@@ -699,21 +690,18 @@ try_dscp_v6(void)
 }
 
 static void
-try_dscp(void)
-{
+try_dscp(void) {
 	try_dscp_v4();
 	try_dscp_v6();
 }
 
 static void
-initialize_dscp(void)
-{
+initialize_dscp(void) {
 	RUNTIME_CHECK(isc_once_do(&once_dscp, try_dscp) == ISC_R_SUCCESS);
 }
 
 unsigned int
-isc_net_probedscp(void)
-{
+isc_net_probedscp(void) {
 	initialize_dscp();
 	return (dscp_result);
 }
@@ -721,10 +709,9 @@ isc_net_probedscp(void)
 #if defined(USE_SYSCTL_PORTRANGE)
 #if defined(HAVE_SYSCTLBYNAME)
 static isc_result_t
-getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high)
-{
-	int	    port_low, port_high;
-	size_t	    portlen;
+getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high) {
+	int port_low, port_high;
+	size_t portlen;
 	const char *sysctlname_lowport, *sysctlname_hiport;
 
 	if (af == AF_INET) {
@@ -735,17 +722,18 @@ getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high)
 		sysctlname_hiport = SYSCTL_V6PORTRANGE_HIGH;
 	}
 	portlen = sizeof(port_low);
-	if (sysctlbyname(sysctlname_lowport, &port_low, &portlen, NULL, 0) <
-	    0) {
+	if (sysctlbyname(sysctlname_lowport, &port_low, &portlen, NULL, 0) < 0)
+	{
 		return (ISC_R_FAILURE);
 	}
 	portlen = sizeof(port_high);
-	if (sysctlbyname(sysctlname_hiport, &port_high, &portlen, NULL, 0) <
-	    0) {
+	if (sysctlbyname(sysctlname_hiport, &port_high, &portlen, NULL, 0) < 0)
+	{
 		return (ISC_R_FAILURE);
 	}
-	if ((port_low & ~0xffff) != 0 || (port_high & ~0xffff) != 0)
+	if ((port_low & ~0xffff) != 0 || (port_high & ~0xffff) != 0) {
 		return (ISC_R_RANGE);
+	}
 
 	*low = (in_port_t)port_low;
 	*high = (in_port_t)port_high;
@@ -754,8 +742,7 @@ getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high)
 }
 #else  /* !HAVE_SYSCTLBYNAME */
 static isc_result_t
-getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high)
-{
+getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high) {
 	int mib_lo4[4] = SYSCTL_V4PORTRANGE_LOW;
 	int mib_hi4[4] = SYSCTL_V4PORTRANGE_HIGH;
 	int mib_lo6[4] = SYSCTL_V6PORTRANGE_LOW;
@@ -784,8 +771,9 @@ getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high)
 		return (ISC_R_FAILURE);
 	}
 
-	if ((port_low & ~0xffff) != 0 || (port_high & ~0xffff) != 0)
+	if ((port_low & ~0xffff) != 0 || (port_high & ~0xffff) != 0) {
 		return (ISC_R_RANGE);
+	}
 
 	*low = (in_port_t)port_low;
 	*high = (in_port_t)port_high;
@@ -796,12 +784,11 @@ getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high)
 #endif /* USE_SYSCTL_PORTRANGE */
 
 isc_result_t
-isc_net_getudpportrange(int af, in_port_t *low, in_port_t *high)
-{
+isc_net_getudpportrange(int af, in_port_t *low, in_port_t *high) {
 	int result = ISC_R_FAILURE;
 #if !defined(USE_SYSCTL_PORTRANGE) && defined(__linux)
 	FILE *fp;
-#endif
+#endif /* if !defined(USE_SYSCTL_PORTRANGE) && defined(__linux) */
 
 	REQUIRE(low != NULL && high != NULL);
 
@@ -816,7 +803,7 @@ isc_net_getudpportrange(int af, in_port_t *low, in_port_t *high)
 	 */
 	fp = fopen("/proc/sys/net/ipv4/ip_local_port_range", "r");
 	if (fp != NULL) {
-		int	     n;
+		int n;
 		unsigned int l, h;
 
 		n = fscanf(fp, "%u %u", &l, &h);
@@ -827,9 +814,9 @@ isc_net_getudpportrange(int af, in_port_t *low, in_port_t *high)
 		}
 		fclose(fp);
 	}
-#else
+#else  /* if defined(USE_SYSCTL_PORTRANGE) */
 	UNUSED(af);
-#endif
+#endif /* if defined(USE_SYSCTL_PORTRANGE) */
 
 	if (result != ISC_R_SUCCESS) {
 		*low = ISC_NET_PORTRANGELOW;
@@ -840,33 +827,33 @@ isc_net_getudpportrange(int af, in_port_t *low, in_port_t *high)
 }
 
 void
-isc_net_disableipv4(void)
-{
+isc_net_disableipv4(void) {
 	initialize();
-	if (ipv4_result == ISC_R_SUCCESS)
+	if (ipv4_result == ISC_R_SUCCESS) {
 		ipv4_result = ISC_R_DISABLED;
+	}
 }
 
 void
-isc_net_disableipv6(void)
-{
+isc_net_disableipv6(void) {
 	initialize();
-	if (ipv6_result == ISC_R_SUCCESS)
+	if (ipv6_result == ISC_R_SUCCESS) {
 		ipv6_result = ISC_R_DISABLED;
+	}
 }
 
 void
-isc_net_enableipv4(void)
-{
+isc_net_enableipv4(void) {
 	initialize();
-	if (ipv4_result == ISC_R_DISABLED)
+	if (ipv4_result == ISC_R_DISABLED) {
 		ipv4_result = ISC_R_SUCCESS;
+	}
 }
 
 void
-isc_net_enableipv6(void)
-{
+isc_net_enableipv6(void) {
 	initialize();
-	if (ipv6_result == ISC_R_DISABLED)
+	if (ipv6_result == ISC_R_DISABLED) {
 		ipv6_result = ISC_R_SUCCESS;
+	}
 }
