@@ -13,27 +13,27 @@
 
 #include <isc/os.h>
 
-static BOOL	   bInit = FALSE;
+static BOOL bInit = FALSE;
 static SYSTEM_INFO SystemInfo;
 
 static void
-initialize_action(void)
-{
-	if (bInit)
+initialize_action(void) {
+	if (bInit) {
 		return;
+	}
 
 	GetSystemInfo(&SystemInfo);
 	bInit = TRUE;
 }
 
 unsigned int
-isc_os_ncpus(void)
-{
+isc_os_ncpus(void) {
 	long ncpus;
 	initialize_action();
 	ncpus = SystemInfo.dwNumberOfProcessors;
-	if (ncpus <= 0)
+	if (ncpus <= 0) {
 		ncpus = 1;
+	}
 
 	return ((unsigned int)ncpus);
 }
