@@ -9,15 +9,20 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
-#include <atf-c.h>
+#if HAVE_CMOCKA
 
+#include <sched.h> /* IWYU pragma: keep */
+#include <setjmp.h>
+#include <stdarg.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
+#define UNIT_TESTING
+#include <cmocka.h>
+
 #include <isc/buffer.h>
 #include <isc/lex.h>
 #include <isc/log.h>
@@ -29,33 +34,33 @@
 #include <isccfg/grammar.h>
 #include <isccfg/namedconf.h>
 
-#define CHECK(r) \
-	do { \
-		result = (r); \
+#define CHECK(r)                             \
+	do {                                 \
+		result = (r);                \
 		if (result != ISC_R_SUCCESS) \
-			goto cleanup; \
+			goto cleanup;        \
 	} while (0)
 
 isc_mem_t *mctx = NULL;
 isc_log_t *lctx = NULL;
-static isc_logcategory_t categories[] = {
-		{ "",                0 },
-		{ "client",          0 },
-		{ "network",         0 },
-		{ "update",          0 },
-		{ "queries",         0 },
-		{ "unmatched",       0 },
-		{ "update-security", 0 },
-		{ "query-errors",    0 },
-		{ NULL,              0 }
-};
+static isc_logcategory_t categories[] = { { "", 0 },
+					  { "client", 0 },
+					  { "network", 0 },
+					  { "update", 0 },
+					  { "queries", 0 },
+					  { "unmatched", 0 },
+					  { "update-security", 0 },
+					  { "query-errors", 0 },
+					  { NULL, 0 } };
 
 static void
 cleanup() {
-	if (lctx != NULL)
+	if (lctx != NULL) {
 		isc_log_destroy(&lctx);
-	if (mctx != NULL)
+	}
+	if (mctx != NULL) {
 		isc_mem_destroy(&mctx);
+	}
 }
 
 static isc_result_t
@@ -63,7 +68,7 @@ setup() {
 	isc_result_t result;
 
 	isc_mem_debugging |= ISC_MEM_DEBUGRECORD;
-	CHECK(isc_mem_create(0, 0, &mctx));
+	isc_mem_create(&mctx);
 
 	isc_logdestination_t destination;
 	isc_logconfig_t *logconfig = NULL;
@@ -76,31 +81,27 @@ setup() {
 	destination.file.name = NULL;
 	destination.file.versions = ISC_LOG_ROLLNEVER;
 	destination.file.maximum_size = 0;
-	CHECK(isc_log_createchannel(logconfig, "stderr",
-				    ISC_LOG_TOFILEDESC,
-				    ISC_LOG_DYNAMIC,
-				    &destination, 0));
+	CHECK(isc_log_createchannel(logconfig, "stderr", ISC_LOG_TOFILEDESC,
+				    ISC_LOG_DYNAMIC, &destination, 0));
 	CHECK(isc_log_usechannel(logconfig, "stderr", NULL, NULL));
 
 	return (ISC_R_SUCCESS);
 
-  cleanup:
+cleanup:
 	cleanup();
 	return (result);
 }
 
-ATF_TC(parse_buffer);
-ATF_TC_HEAD(parse_buffer, tc) {
-	atf_tc_set_md_var(tc, "descr", "cfg_parse_buffer");
-}
-ATF_TC_BODY(parse_buffer, tc) {
+/* test cfg_parse_buffer() */
+static void
+parse_buffer_test(void **state) {
 	isc_result_t result;
 	unsigned char text[] = "options\n{\nrecursion yes;\n};\n";
 	isc_buffer_t buf1, buf2;
 	cfg_parser_t *p1 = NULL, *p2 = NULL;
 	cfg_obj_t *c1 = NULL, *c2 = NULL;
 
-	UNUSED(tc);
+	UNUSED(state);
 
 	setup();
 
@@ -109,24 +110,24 @@ ATF_TC_BODY(parse_buffer, tc) {
 
 	/* Parse with default line numbering */
 	result = cfg_parser_create(mctx, lctx, &p1);
-	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
+	assert_int_equal(result, ISC_R_SUCCESS);
 
-	result = cfg_parse_buffer3(p1, &buf1, "text1", 0,
-				   &cfg_type_namedconf, &c1);
-	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
-	ATF_REQUIRE_EQ(p1->line, 5);
+	result = cfg_parse_buffer(p1, &buf1, "text1", 0, &cfg_type_namedconf, 0,
+				  &c1);
+	assert_int_equal(result, ISC_R_SUCCESS);
+	assert_int_equal(p1->line, 5);
 
 	isc_buffer_init(&buf2, &text[0], sizeof(text) - 1);
 	isc_buffer_add(&buf2, sizeof(text) - 1);
 
 	/* Parse with changed line number */
 	result = cfg_parser_create(mctx, lctx, &p2);
-	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
+	assert_int_equal(result, ISC_R_SUCCESS);
 
-	result = cfg_parse_buffer3(p2, &buf2, "text2", 100,
-				   &cfg_type_namedconf, &c2);
-	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
-	ATF_REQUIRE_EQ(p2->line, 104);
+	result = cfg_parse_buffer(p2, &buf2, "text2", 100, &cfg_type_namedconf,
+				  0, &c2);
+	assert_int_equal(result, ISC_R_SUCCESS);
+	assert_int_equal(p2->line, 104);
 
 	cfg_obj_destroy(p1, &c1);
 	cfg_obj_destroy(p2, &c2);
@@ -137,56 +138,65 @@ ATF_TC_BODY(parse_buffer, tc) {
 	cleanup();
 }
 
-ATF_TC(cfg_map_firstclause);
-ATF_TC_HEAD(cfg_map_firstclause, tc) {
-	atf_tc_set_md_var(tc, "descr", "cfg_map_firstclause");
-}
-ATF_TC_BODY(cfg_map_firstclause, tc) {
+/* test cfg_map_firstclause() */
+static void
+cfg_map_firstclause_test(void **state) {
 	const char *name = NULL;
 	const void *clauses = NULL;
 	unsigned int idx;
 
-	UNUSED(tc);
+	UNUSED(state);
 
 	name = cfg_map_firstclause(&cfg_type_zoneopts, &clauses, &idx);
-	ATF_CHECK(name != NULL);
-	ATF_CHECK(clauses != NULL);
-	ATF_CHECK_EQ(idx, 0);
+	assert_non_null(name);
+	assert_non_null(clauses);
+	assert_int_equal(idx, 0);
 }
 
-ATF_TC(cfg_map_nextclause);
-ATF_TC_HEAD(cfg_map_nextclause, tc) {
-	atf_tc_set_md_var(tc, "descr", "cfg_map_firstclause");
-}
-ATF_TC_BODY(cfg_map_nextclause, tc) {
+/* test cfg_map_nextclause() */
+static void
+cfg_map_nextclause_test(void **state) {
 	const char *name = NULL;
 	const void *clauses = NULL;
 	unsigned int idx;
 
-	UNUSED(tc);
+	UNUSED(state);
 
 	name = cfg_map_firstclause(&cfg_type_zoneopts, &clauses, &idx);
-	ATF_REQUIRE(name != NULL);
-	ATF_REQUIRE(clauses != NULL);
-	ATF_REQUIRE_EQ(idx, ISC_R_SUCCESS);
+	assert_non_null(name);
+	assert_non_null(clauses);
+	assert_int_equal(idx, ISC_R_SUCCESS);
 
 	do {
 		name = cfg_map_nextclause(&cfg_type_zoneopts, &clauses, &idx);
 		if (name != NULL) {
-			ATF_CHECK(clauses != NULL);
+			assert_non_null(clauses);
 		} else {
-			ATF_CHECK_EQ(clauses, NULL);
-			ATF_CHECK_EQ(idx, 0);
+			assert_null(clauses);
+			assert_int_equal(idx, 0);
 		}
 	} while (name != NULL);
 }
 
-/*
- * Main
- */
-ATF_TP_ADD_TCS(tp) {
-	ATF_TP_ADD_TC(tp, parse_buffer);
-	ATF_TP_ADD_TC(tp, cfg_map_firstclause);
-	ATF_TP_ADD_TC(tp, cfg_map_nextclause);
-	return (atf_no_error());
+int
+main(void) {
+	const struct CMUnitTest tests[] = {
+		cmocka_unit_test(parse_buffer_test),
+		cmocka_unit_test(cfg_map_firstclause_test),
+		cmocka_unit_test(cfg_map_nextclause_test),
+	};
+
+	return (cmocka_run_group_tests(tests, NULL, NULL));
 }
+
+#else /* HAVE_CMOCKA */
+
+#include <stdio.h>
+
+int
+main(void) {
+	printf("1..0 # Skipped: cmocka not available\n");
+	return (0);
+}
+
+#endif /* if HAVE_CMOCKA */
